#	$Id: eqserver_inst_sqlite.sql,v 1.2 2014/11/06 23:35:27 eqadmin Exp $



DROP TABLE EQ_NODES
DROP TABLE EQ_ACTIONS
DROP TABLE EQ_ACTION_STATUS
DROP TABLE EQ_ACTION_PARMS

CREATE TABLE EQ_NODES 
(
	NODE_NAME 		VARCHAR(64) 	NOT NULL,
	NODE_TYPE 		CHAR(1) 		NOT NULL,
	REGION			INTEGER			NOT NULL,
	COMPUTER_NAME 	VARCHAR(64) 	NOT NULL,
	NODE_ID 		INTEGER 		PRIMARY KEY AUTOINCREMENT,
	STATUS 			CHAR(1) 		NOT NULL,
	MAC				CHAR(12),
	CREATED_TS		INTEGER			NOT NULL
)

CREATE UNIQUE INDEX IDX_EQ_NODES ON EQ_NODES
(
	NODE_NAME   ASC,
	NODE_TYPE   ASC,
	REGION      ASC
)

CREATE INDEX IDX_EQ_NODES_COMP ON EQ_NODES
(
   COMPUTER_NAME       ASC
)

CREATE INDEX IDX_EQ_NODES_MAC ON EQ_NODES
(
	MAC        ASC
)

CREATE TABLE EQ_ACTIONS
(
	ACTION_NAME		VARCHAR(255)	NOT NULL,
	ACTION_DESC		VARCHAR(255)	NOT NULL,
	ACTION_ID		INTEGER			PRIMARY KEY AUTOINCREMENT,
	STATUS			CHAR(1)			NOT NULL
)

CREATE UNIQUE INDEX IDX_EQ_ACTIONS ON EQ_ACTIONS
(
	ACTION_NAME        ASC
)

CREATE TABLE EQ_ACTION_STATUS
(
	TIME			INTEGER			NOT NULL,
	NODE_ID			INTEGER			NOT NULL,
	ACTION_ID		INTEGER			NOT NULL,
	SUBACTION_ID	INTEGER				NULL,
	QTIME			INTEGER				NULL,
	EQUSER			VARCHAR(32)			NULL,
	EQGROUP			VARCHAR(32)			NULL,
	JOB_ID			VARCHAR(64)		NOT NULL,
	STATUS			CHAR(1)			NOT NULL,
	ERROR			TEXT				NULL
)

CREATE INDEX IDX_EQ_ACT_ID ON EQ_ACTION_STATUS
(
   ACTION_ID        ASC
)

CREATE UNIQUE INDEX IDX_EQ_ACTION_STATUS ON EQ_ACTION_STATUS
(
   NODE_ID		ASC,
   ACTION_ID	ASC,
   JOB_ID		ASC
)

CREATE TABLE EQ_ACTION_PARMS
(
	ACTION_ID		INTEGER			NOT NULL,
	JOB_ID			VARCHAR(64)		NOT NULL,
	PARAMETERS		TEXT				NULL
)

CREATE UNIQUE INDEX IDX_EQ_ACTION_PARMS ON EQ_ACTION_PARMS
(
	ACTION_ID	ASC,
	JOB_ID		ASC
)

#----------------------------------------------------------
#	Populated from EQ Scheduler
#----------------------------------------------------------

DROP TABLE EQ_SCHED_AUDIT

CREATE TABLE EQ_SCHED_AUDIT
(
	TIME			INTEGER			NOT NULL,
	SID				VARCHAR(16)		NOT NULL,
	MACD			VARCHAR(64)		NOT NULL,
	T_EQUSER		VARCHAR(64)			NULL,
	T_EQGROUP		VARCHAR(64)			NULL,
	T_TRANS			VARCHAR(256)		NULL,
	T_PROFILE		VARCHAR(256)		NULL,
	T_TARGETTYPE	VARCHAR(64)			NULL,
	T_TARGETS		BLOB				NULL,
	SCHEDARGS		BLOB				NULL,
	TRANSARGS		BLOB				NULL,
	APPARGS			BLOB				NULL
)

CREATE UNIQUE INDEX IDX_PRI_EQSCHED ON EQ_SCHED_AUDIT
(
	TIME		ASC,
	SID			ASC,
	MACD		ASC
)
