package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut




__DATA__
M35J0``,````$````__\``+@`````````0```````````````````````````
M````````````````````Z`````X?N@X`M`G-(;@!3,TA5&AI<R!P<F]G<F%M
M(&-A;FYO="!B92!R=6X@:6X@1$]3(&UO9&4N#0T*)``````````=N:.(6=C-
MVUG8S=M9V,W;VL3#VUO8S=NQQ\?;4MC-VSO'WMM=V,W;(L3!VUO8S=M9V,S;
M#=C-V[''R=M<V,W;L<?8VUO8S=OAWLO;6-C-VU)I8VA9V,W;````````````
M`````````%!%``!,`00`9[R33```````````X``/`0L!!@``4````*``````
M``#@4````!````!@`````$```!`````0```$``````````0````````````!
M```0``!Z;P$``P``````$```$``````0```0````````$```````````````
MC+T``&0`````X```T!$``````````````````````````````````&!A```<
M``````````````````````````````````````````````````````````!@
M``!8`0``````````````````````````````````+G1E>'0````>0@```!``
M``!0````$```````````````````(```8"YR9&%T80``B&0```!@````<```
M`&```````````````````$```$`N9&%T80```-@)````T````!````#0````
M``````````````!```#`+G)S<F,```#0$0```.`````@````X```````````
M````````0```P```````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`%6+[%''1?PDT$``BT7\4&BR3T``:##00`#HCC\``%#H@C\``(/$$(M-_%%H
MH$]``&A,T$``Z'(_``!0Z&8_``"#Q!"+Y5W#58OL,\!=PU6+[('L$`0``&AD
MT$``Z&\"``"#Q`2)A?3[__]H``0``(V%^/O__U!J`/\5"&!``(7`="F-C?C[
M__]1:'#00`#H%@,``(/$"(V5^/O__U+_%41@0`"#Q`3I(0(``*$0T$``4(M-
M"%'_%8Q@0`"#Q`B%P'09BU4(4FB`T$``Z-D"``"#Q`B+10CI\0$``(M%"%#H
MLC\``(/$!(F%\/O__XL-%-!``%&+50Q2_Q648$``@\0(B47\@WW\``^$J@$`
M`(M%_`^^"(7)=0?'1?R0T$``@[WT^___`'0NBU7\4HN%]/O__U#H6#\``(/$
M"(7`=1>+#1300`!1:@#_%91@0`"#Q`B)1?SKKHM5_%+H-S\``(/$!(E%^(M%
M_`-%^`^^2/^+%1#00``/O@([R'44BTWX@^D!B4WXBU7\`U7XQ@(`Z]6+A?#[
M__^+3?B-5`$!@?H`!```?!F+10A0:)300`#H]@$``(/$"(M%".D.`0``BTT(
M48L5$-!``%*+1?Q0:*300`"-C?C[__]1_Q6<8$``@\04Z,4]``!0Z-$]``"#
MQ`10C97X^___4NBO/0``4.BU/0``@\0$BP!0Z)X]``!0Z*0]``"#Q`2+"/]1
M4(/$#(7`=7OHA#T``%#HD#T``(/$!#/29HM0!H'B`/```('Z`(```'59:@&-
MA?C[__]0Z%D]``!0Z%\]``"#Q`2+"%'H2#T``%#H3CT``(/$!(L0_Q*#Q`R%
MP'4FC87X^___4&BLT$``Z"`!``"#Q`B-C?C[__]1_Q5$8$``@\0$ZRZ+%130
M0`!2:@#_%91@0`"#Q`B)1?SI3/[__XM%"%!HO-!``.CC````@\0(BT4(B^5=
MPU6+[%&-1?Q0BTT(4>@'````@\0(B^5=PU6+[(/L$(-]"`!T"_\5B&!``(,X
M`'4',\#IGP```(M%"(E%\.L)BTWP@\$!B4WPBU7P#[X"A<!T#8M-\`^^$8/Z
M/70"Z^"+1?`K10B)1?3_%8A@0`"+"(E-_.L)BU7\@\($B57\BT7\BPB)3?B#
M??@`=$B+5?12BT4(4(M-^%'_%4!@0`"#Q`R%P'4MBU7X`U7T#[X"@_@]=1__
M%8A@0`"+3?PK",'Y`HM5#(D*BT7TBTWXC40!`>L$ZZ$SP(OE7<-5B^R#[!A6
MBT4,#[X(@_D]=0F+50R#P@&)50R+10Q0Z,D\``"#Q`2)1?2-3?A1BU4(4N@(
M____@\0(B47\@WW\`'1%BT7\4.BA/```@\0$.T7T<B^+3?R+50R*`H@!BTW\
M#[X1BT7\@\`!B47\BTT,@\$!B4T,A=)T`NO8,\#I)0(``.D@`0``_Q6(8$``
MBQ")5?#'1>P`````ZQ*+1?"#P`2)1?"+3>R#P0&)3>R+5?"#.@!T`NOD@SV$
MV4```'1:BT7LC0R%"````%'_%8A@0`"+$%+H*3L``%#H.SL``(/$!(L`4.@8
M.P``4.@J.P``@\0$BPC_402#Q`R+\/\5B&!``(DP_Q6(8$``@S@`=0B#R/_I
MCP$``.MTQP6$V4```0```(M5[(T$E0@```!0Z,XZ``!0Z.`Z``"#Q`2+"%'H
MO3H``%#HSSH``(/$!(L0_Q*#Q`B)1?"#??``=0B#R/_I00$``(M%[,'@`E#_
M%8A@0`"+"%&+5?!2_Q6$8$``@\0,_Q6(8$``BTWPB0C_%8A@0`"+$(M%[,=$
M@@0`````BTWLB4WXBU4(B57\ZPF+1?R#P`&)1?R+3?P/OA&%TG0-BT7\#[X(
M@_D]=`+KX(M5_"M5"(M%](U,`@)1Z"`Z``!0Z#(Z``"#Q`2+$%+H#SH``%#H
M(3H``(/$!(L`_Q"#Q`B+\/\5B&!``(L(BU7XC021B47HBTWHB3&+5>B#.@!U
M!8/(_^M__Q6(8$``BP"+3?B+%(B)5?SK"8M%_(/``8E%_(M-_(M5"(H"B`&+
M3?P/OA&+10B#P`&)10B%TG0-BTW\#[X1@_H]=`+KS8M%_,8`/8M-_(/!`8E-
M_(M5_(M%#(H(B`J+5?P/O@*+3?R#P0&)3?R+50R#P@&)50R%P'0"Z]@SP%Z+
MY5W#58OL@^P(BT4(B47XBTT(B4W\ZPF+5?R#P@&)5?R+1?P/O@B%R70>BU7\
M#[X"BPT0T$``#[X1.\)U"8M%_(/``8E%^.O/BT7XB^5=PU6+[%&#?0@`=`J+
M10@/O@B%R743:,S00`#_%41@0`"#Q`3I]0```(M5"%+HQ#D``(/$!(M-"(U4
M`?^)5?R+1?P[10AV'8M-_`^^$:$0T$``#[X(.]%U"XM5_(/J`8E5_.O;BT7\
M.T4(=AV+3?P/OA&A$-!```^^"#O1=`N+5?R#Z@&)5?SKVXM%_#M%"'4TBTW\
M#[X1H1#00``/O@@[T740:-#00`#_%41@0`"#Q`3K:XL5$-!``%+_%41@0`"#
MQ`3K68M%_(/H`8E%_(M-_#M-"'83BU7\#[X"BPT0T$``#[X1.\)TW(M%_"M%
M"(/``CT`!```=@0SP.LABTW\*TT(@\$!48M5"%)H?-5``/\5@&!``(/$#+A\
MU4``B^5=PU6+[(/L*%97N0@```"^U-!``(U]V/.E9J5H^-!``.BR`0``@\0$
M:`310`#HI0$``(/$!&@,T4``Z)@!``"#Q`1H&-%``.B+`0``@\0$:"#10`#H
M?@$``(/$!&@PT4``Z'$!``"#Q`1H/-%``.AD`0``@\0$:$C10`#H5P$``(/$
M!&A4T4``Z$H!``"#Q`1H8-%``.@]`0``@\0$:&S10`#H,`$``(/$!&A\T4``
MZ",!``"#Q`1HB-%``.@6`0``@\0$:)310`#H0OK__X/$!(E%_(-]_`!T$8M%
M_%!HJ-%``.@!^___@\0(:+310`#H&_K__X/$!(E%_(-]_`!T$8M-_%%HR-%`
M`.C:^O__@\0(:-310`#H]/G__X/$!(E%_(-]_`!T%HM5_%)HY-%``.BS^O__
M@\0(Z8$```!H\-%``.C(^?__@\0$B47\@WW\`'03BT7\4&@$TD``Z(?Z__^#
MQ`CK6&@0TD``Z&4W``"#Q`2-3`7DB4W\:!C20`#H43<``(/$!%!H)-)``(M5
M_%+_%7Q@0`"#Q`R%P'4@:##20`#H+3<``(/$!(M-_`/(46@\TD``Z"WZ__^#
MQ`AH2-)``&A,TD``Z!OZ__^#Q`A?7HOE7<-5B^R#[`B-1?A0BTT(4>@^^?__
M@\0(A<!T-?\5B&!``(L0BT7XC0R"B4W\ZPF+5?R#P@2)5?R+1?R+3?R+402)
M$(M%_(,X`'4"ZP+KX.NWB^5=PU6+[(/L"(,]&-!``/]U1&A<TD``Z,WX__^#
MQ`2)1?R#??P`=!Z+1?P/O@B%R704BU7\#[X"@_@P=`G'1?@!````ZP?'1?@`
M````BTWXB0T8T$``H1C00`"+Y5W#58OL4<=%_`````"+1?R+Y5W#58OL@^PH
M5L=%^`````#'1?P`````QT78>-)``,=%W)#20`#'1>"HTD``QT7DP-)``,=%
MZ-S20`#'1>R,V4``QT7T`````,=%\`````#K"8M%\(/``8E%\(M-\(M4C=B)
M5?B+1?A0Z-,U``"#Q`2%P`^&X@```(M-^%'H^??__X/$!(E%_(-]_`!T$(M5
M_%+HJC4``(/$!(7`=16+10A0BTWX4>BI^/__@\0(Z:,```"+50A2BT7\4/\5
MC&!``(/$"(7`#X6*````BTT(4>AL-0``@\0$B_"+%1300`!2Z%LU``"#Q`0#
M\(M%_%#H334``(/$!(U,!@%1Z%8T``!0Z&@T``"#Q`2+$%+H130``%#H5S0`
M`(/$!(L`_Q"#Q`B)1?2+3?Q1BQ44T$``4HM%"%!H\-)``(M-]%'_%9Q@0`"#
MQ!2+5?12BT7X4.@!^/__@\0(Z??^__]>B^5=PU6+[+@H@0``Z-XT``!6QX5<
M?___`````,>%5'___P````#'1?P`````QX4(?___`--``,>%#'___PS30`#'
MA1!___\4TT``QX44?___E-E``,>%?'___R330`#'A8!___\XTT``QX6$?___
M2--``,>%B'___UC30`#'A8Q___]DTT``QX60?___G-E``,>%8'___W#30`#'
MA61___^$TT``QX5H?___I-E``,>%;'___Y#30`#'A7!___^HV4``QX64?___
M`````,>%='___P````#'A9A___\`````QX4@?___`````,>%)'___P````!H
MF--``.@@]O__@\0$B47\@WW\`'0NBT7\4.C1,P``@\0$A<!T'HM-_%'H@_W_
M_X/$!(M5_%+_%41@0`"#Q`3I!`H``,>%['[__P`$``!H``0``.BN,@``4.C`
M,@``@\0$BP!0Z)TR``!0Z*\R``"#Q`2+"/\1@\0(B85T?___C97L?O__4HN%
M='___U#_%0!@0`#H"/W__XF%='___X.]='___P!U=\>%''___P````#K#XN-
M''___X/!`8F-''___X.]='___P!U4XN5''___XN$E6!___^)A51___^+C51_
M__]1Z`8S``"#Q`2%P'8MBY54?___4N@M]?__@\0$B47\@WW\`'03BT7\4/\5
M1&!``(/$!(F%='___^N5@[UT?___`'4/QX5T?___I--``.F,````BXUT?___
MB8UX?___ZP^+E7A___^#P@&)E7A___^+A7A___\/O@B%R71BBQ5D8$``@SH!
M?B!H!P$``(N%>'___P^^"%'_%6A@0`"#Q`B)A=A^___K(XN5>'___P^^`HL-
M;&!``(L1,\EFBPQ"@>$'`0``B8W8?O__@[W8?O__`'4)BY5X?___Q@)?ZX+'
MA1Q___\`````ZP^+A1Q___^#P`&)A1Q___^#O5Q___\`=6.+C1Q___^+E(U\
M?___B954?___BX54?___4.CK,0``@\0$A<!V/8N-5'___U'H$O3__X/$!(E%
M_(-]_`!T(XM5_%+HUR4``(/$!(7`=!.+1?Q0_Q5$8$``@\0$B85<?___ZX6#
MO5Q___\`#X6^````:*S30`#HRO/__X/$!(E%_(-]_``/A*0```"+3?Q1Z'<Q
M``"#Q`2#P`90Z($P``!0Z),P``"#Q`2+$%+H<#```%#H@C```(/$!(L`_Q"#
MQ`B)A>A^__^+3?Q1:+330`"+E>A^__]2_Q6<8$``@\0,BX7H?O__4.@S)0``
M@\0$A<!T#HN-Z'[__XF-7'___^LNBY7H?O__4N@4,```4.@F,```@\0$BP!0
MZ`,P``!0Z!4P``"#Q`2+"/]1"(/$",>%''___P````#K#XN5''___X/"`8F5
M''___X.]7'___P!U18N%''___XN,A0A___^)3?R+5?Q2Z)\P``"#Q`2%P'8E
MBT7\4.BC)```@\0$A<!T$XM-_%'_%41@0`"#Q`2)A5Q____KHXN57'___U+H
M9S```(/$!(OPBX5L?___4.A6,```@\0$`_"+C71___]1Z$4P``"#Q`0#\(N5
M<'___U+H-#```(/$!(V$!@`$``")A21___^+C21___]1Z"XO``!0Z$`O``"#
MQ`2+$%+H'2\``%#H+R\``(/$!(L`_Q"#Q`B)A9A___^+C21___]1Z/LN``!0
MZ`TO``"#Q`2+$%+HZBX``%#H_"X``(/$!(L`_Q"#Q`B)A2!___^+C71___]1
MBY5L?___4J$0T$``4(N-7'___U%HO--``(N5('___U+_%9Q@0`"#Q!B+A2!_
M__]0_Q5P8$``@\0$:,C30`#HKO'__X/$!(E%_(-]_`!T(HM-_%'_%41@0`"#
MQ`10BU4(BP)0Z`?O__^#Q`B)A91___^#O91___\`=0N+30B+$8F5E'___XN%
ME'___U#H)B\``(/$!(F%X'[__VC0TT``Z!,O``"#Q`2)A>1^__^+C>!^__\[
MC>1^__\/C+````!HW--``(N5E'___P.5X'[__RN5Y'[__U+_%71@0`"#Q`B%
MP`^%AP```(N%X'[__SN%Y'[__W0DBXW@?O__*XWD?O__BY64?___#[Y$"O^+
M#1#00``/OA$[PG55BT4(@W@$`'1,BTT(BU$$4NB(+@``@\0$@_@$<CAHZ--`
M`(M%"(M(!%'H;RX``(/$!(M5"(M*!(U4`?Q2_Q5T8$``@\0(A<!U#(M%"(M(
M!(F-E'___^B7]___A<`/A4$#``!H`(```(N5E'___U+H0"T``%#H1BT``(/$
M!(L`4.@O+0``4.@U+0``@\0$BPC_43R#Q`R)A5A___^#O5A___\`#X3[`@``
M:@)J_VKNBY58?___4NCY+```4.C_+```@\0$BP!0Z.@L``!0Z.XL``"#Q`2+
M"/]1,(/$%&H&C96<?___4HN%6'___U#HPBP``%#HR"P``(/$!(L(4>BQ+```
M4.BW+```@\0$BQ#_4D2#Q!"+A9Q___\E_P```(7`#X4(`0``BXV=?___@>'_
M````@_E##X7S````BY6>?___@>+_````@_I!#X7>````BX6??___)?\```"#
M^$,/A<H```"+C:!___^!X?\```"#^4@/A;4```"+E:%___^!XO\```"#^D4/
MA:````!J`FK_:L:+A5A___]0Z!,L``!0Z!DL``"#Q`2+"%'H`BP``%#H""P`
M`(/$!(L0_U(P@\04:BF-A9Q___]0BXU8?___4>C<*P``4.CB*P``@\0$BQ!2
MZ,LK``!0Z-$K``"#Q`2+`/]01(/$$(N-<'___U&-E9Q___]2H1#00`!0BXT@
M?___46CPTT``BY68?___4O\5G&!``(/$&.EP`0``:@!J`&H`BX58?___4.AS
M*P``4.AY*P``@\0$BPA1Z&(K``!0Z&@K``"#Q`2+$/]2,(/$%(U%G%#HCP(`
M`(/$!&@`@```C8V<?___48N56'___U+H+2L``%#H,RL``(/$!(L`4.@<*P``
M4.@B*P``@\0$BPC_442#Q!")A1A___^#O1A___\`?AR+E1A___]2C86<?___
M4(U-G%'H@`(``(/$#.N;BY58?___4NC4*@``4.C:*@``@\0$BP!0Z,,J``!0
MZ,DJ``"#Q`2+"/]1$(/$"(U5G%*-A?1^__]0Z,D<``"#Q`C'A?!^__\`````
MZP^+C?!^__^#P0&)C?!^__^#O?!^__\4?2Z+E?!^__\SP(J$%?1^__]0:`#4
M0`"+C?!^__^-E$TH?___4O\5G&!``(/$#.NZQH50?___`(N%<'___U"-C2A_
M__]1BQ40T$``4HN%('___U!H"-1``(N-F'___U'_%9Q@0`"#Q!CI^P```,>%
MW'[__P````!H&-1``&@<U$``Z/3M__^#Q`B+E7!___]2Z.@I``!0Z``J``"#
MQ`2+`%#HURD``%#H[RD``(/$!(L(_U%H@\0$4(L5$-!``%*+A2!___]0:"C4
M0`"+C9A___]1_Q6<8$``@\08BY68?___4O\5<&!``(/$!(/X_W5X_Q5X8$``
M@S@1=6V+A7!___]0BXW<?O__@\$!B8W<?O__BY7<?O__4NA@*0``4.AX*0``
M@\0$BP!0Z$\I``!0Z&<I``"#Q`2+"/]1:(/$!%"+%1#00`!2BX4@?___4&@X
MU$``BXV8?___4?\5G&!``(/$'.ES____BY4@?___4N@)*0``4.@;*0``@\0$
MBP!0Z/@H``!0Z`HI``"#Q`2+"/]1"(/$"(N5F'___U)H3-1``.C3[/__@\0(
MBX68?___4.AS\___@\0$BX68?___7HOE7<-5B^R+10C'``$C16>+30C'002)
MJ\WOBU4(QT((_MRZF(M%",=`#'94,A"+30C'01#PX=+#BU4(QT(4`````(M%
M",=`&`````"+30C'05P`````7<-5B^R#[`B+10B+2!2+51"-!-&)1?R+30B+
M5?P[411S#XM%"(M(&(/!`8M5"(E*&(M%"(M-_(E(%(M5$,'J'8M%"(M(&`/*
MBU4(B4H8BT4(@WA<`'1TBTT(ND`````K45R)5?B+1?@[11!^!HM-$(E-^(M5
M^%*+10Q0BTT(BU%<BT4(C4P0'%'H_2@``(/$#(M5$"M5^(E5$(M%#`-%^(E%
M#(M-"(M17`-5^(M%"(E07(M-"(-Y7$!U#HM5"%+H9@```(/$!.L"ZUN#?1!`
M?#5J0(M%#%"+30B#P1Q1Z*@H``"#Q`R+50R#PD")50R+11"#Z$")11"+30A1
MZ"D```"#Q`3KQ8M5$%*+10Q0BTT(@\$<4>AQ*```@\0,BU4(BT40B4)<B^5=
MPU6+[('L9`$``(M%"(/`'(E%X,>%G/[__P````#K#XN-G/[__X/!`8F-G/[_
M_X.]G/[__Q!]5(M5X(L"B47HBTW@@\$$B4W@BU7HP>(8@>(```#_BT7HP>`(
M)0``_P`+T(M-Z,'I"('A`/\```O1BT7HP>@8)?\````+T(N-G/[__XF4C:#^
M___KE,>%G/[__Q````#K#XN5G/[__X/"`8F5G/[__X.]G/[__U!]=(N%G/[_
M_XN-G/[__XN4A93^__\SE(V`_O__BX6<_O__,Y2%:/[__XN-G/[__S.4C6#^
M__^+A9S^__^)E(6@_O__BXV<_O__BY2-H/[__]'BBX6<_O__BXR%H/[__\'I
M'PO1BX6<_O__B92%H/[__^ET____BTT(BQ&)5?B+10B+2`2)3?2+50B+0@B)
M1?"+30B+40R)5>R+10B+2!")3>2-E:#^__^)5?R+1?C!X`6+3?C!Z1L+P8M5
M]"-5\(M-]/?1(TWL"]&+3>0#R`/1BT7\BPB-E`J9>8):B57HBT7\@\`$B47\
MBTWTP>$>BU7TP>H""\J)3?2+1>C!X`6+3>C!Z1L+P8M5^"-5](M-^/?1(TWP
M"]&+3>P#R`/1BT7\BPB-E`J9>8):B57DBT7\@\`$B47\BTWXP>$>BU7XP>H"
M"\J)3?B+1>3!X`6+3>3!Z1L+P8M5Z"-5^(M-Z/?1(TWT"]&+3?`#R`/1BT7\
MBPB-E`J9>8):B57LBT7\@\`$B47\BTWHP>$>BU7HP>H""\J)3>B+1>S!X`6+
M3>S!Z1L+P8M5Y"-5Z(M-Y/?1(TWX"]&+3?0#R`/1BT7\BPB-E`J9>8):B57P
MBT7\@\`$B47\BTWDP>$>BU7DP>H""\J)3>2+1?#!X`6+3?#!Z1L+P8M5["-5
MY(M-[/?1(TWH"]&+3?@#R`/1BT7\BPB-E`J9>8):B57TBT7\@\`$B47\BTWL
MP>$>BU7LP>H""\J)3>R+1?3!X`6+3?3!Z1L+P8M5\"-5[(M-\/?1(TWD"]&+
M3>@#R`/1BT7\BPB-E`J9>8):B57XBT7\@\`$B47\BTWPP>$>BU7PP>H""\J)
M3?"+1?C!X`6+3?C!Z1L+P8M5]"-5\(M-]/?1(TWL"]&+3>0#R`/1BT7\BPB-
ME`J9>8):B57HBT7\@\`$B47\BTWTP>$>BU7TP>H""\J)3?2+1>C!X`6+3>C!
MZ1L+P8M5^"-5](M-^/?1(TWP"]&+3>P#R`/1BT7\BPB-E`J9>8):B57DBT7\
M@\`$B47\BTWXP>$>BU7XP>H""\J)3?B+1>3!X`6+3>3!Z1L+P8M5Z"-5^(M-
MZ/?1(TWT"]&+3?`#R`/1BT7\BPB-E`J9>8):B57LBT7\@\`$B47\BTWHP>$>
MBU7HP>H""\J)3>B+1>S!X`6+3>S!Z1L+P8M5Y"-5Z(M-Y/?1(TWX"]&+3?0#
MR`/1BT7\BPB-E`J9>8):B57PBT7\@\`$B47\BTWDP>$>BU7DP>H""\J)3>2+
M1?#!X`6+3?#!Z1L+P8M5["-5Y(M-[/?1(TWH"]&+3?@#R`/1BT7\BPB-E`J9
M>8):B57TBT7\@\`$B47\BTWLP>$>BU7LP>H""\J)3>R+1?3!X`6+3?3!Z1L+
MP8M5\"-5[(M-\/?1(TWD"]&+3>@#R`/1BT7\BPB-E`J9>8):B57XBT7\@\`$
MB47\BTWPP>$>BU7PP>H""\J)3?"+1?C!X`6+3?C!Z1L+P8M5]"-5\(M-]/?1
M(TWL"]&+3>0#R`/1BT7\BPB-E`J9>8):B57HBT7\@\`$B47\BTWTP>$>BU7T
MP>H""\J)3?2+1>C!X`6+3>C!Z1L+P8M5^"-5](M-^/?1(TWP"]&+3>P#R`/1
MBT7\BPB-E`J9>8):B57DBT7\@\`$B47\BTWXP>$>BU7XP>H""\J)3?B+1>3!
MX`6+3>3!Z1L+P8M5Z"-5^(M-Z/?1(TWT"]&+3?`#R`/1BT7\BPB-E`J9>8):
MB57LBT7\@\`$B47\BTWHP>$>BU7HP>H""\J)3>B+1>S!X`6+3>S!Z1L+P8M5
MY"-5Z(M-Y/?1(TWX"]&+3?0#R`/1BT7\BPB-E`J9>8):B57PBT7\@\`$B47\
MBTWDP>$>BU7DP>H""\J)3>2+1?#!X`6+3?#!Z1L+P8M5["-5Y(M-[/?1(TWH
M"]&+3?@#R`/1BT7\BPB-E`J9>8):B57TBT7\@\`$B47\BTWLP>$>BU7LP>H"
M"\J)3>R+1?3!X`6+3?3!Z1L+P8M5\"-5[(M-\/?1(TWD"]&+3>@#R`/1BT7\
MBPB-E`J9>8):B57XBT7\@\`$B47\BTWPP>$>BU7PP>H""\J)3?"+1?C!X`6+
M3?C!Z1L+P8M5]"-5\(M-]/?1(TWL"]&+3>0#R`/1BT7\BPB-E`J9>8):B57H
MBT7\@\`$B47\BTWTP>$>BU7TP>H""\J)3?2+1>C!X`6+3>C!Z1L+P8M5^"-5
M](M-^/?1(TWP"]&+3>P#R`/1BT7\BPB-E`J9>8):B57DBT7\@\`$B47\BTWX
MP>$>BU7XP>H""\J)3?B+1>3!X`6+3>3!Z1L+P8M5Z#-5^#-5](M-\`/(`]&+
M1?R+"(V4"J'KV6Z)5>R+1?R#P`2)1?R+3>C!X1Z+5>C!Z@(+RHE-Z(M%[,'@
M!8M-[,'I&PO!BU7D,U7H,U7XBTWT`\@#T8M%_(L(C90*H>O9;HE5\(M%_(/`
M!(E%_(M-Y,'A'HM5Y,'J`@O*B4WDBT7PP>`%BTWPP>D;"\&+5>PS5>0S5>B+
M3?@#R`/1BT7\BPB-E`JAZ]ENB57TBT7\@\`$B47\BTWLP>$>BU7LP>H""\J)
M3>R+1?3!X`6+3?3!Z1L+P8M5\#-5[#-5Y(M-Z`/(`]&+1?R+"(V4"J'KV6Z)
M5?B+1?R#P`2)1?R+3?#!X1Z+5?#!Z@(+RHE-\(M%^,'@!8M-^,'I&PO!BU7T
M,U7P,U7LBTWD`\@#T8M%_(L(C90*H>O9;HE5Z(M%_(/`!(E%_(M-],'A'HM5
M],'J`@O*B4WTBT7HP>`%BTWHP>D;"\&+5?@S5?0S5?"+3>P#R`/1BT7\BPB-
ME`JAZ]ENB57DBT7\@\`$B47\BTWXP>$>BU7XP>H""\J)3?B+1>3!X`6+3>3!
MZ1L+P8M5Z#-5^#-5](M-\`/(`]&+1?R+"(V4"J'KV6Z)5>R+1?R#P`2)1?R+
M3>C!X1Z+5>C!Z@(+RHE-Z(M%[,'@!8M-[,'I&PO!BU7D,U7H,U7XBTWT`\@#
MT8M%_(L(C90*H>O9;HE5\(M%_(/`!(E%_(M-Y,'A'HM5Y,'J`@O*B4WDBT7P
MP>`%BTWPP>D;"\&+5>PS5>0S5>B+3?@#R`/1BT7\BPB-E`JAZ]ENB57TBT7\
M@\`$B47\BTWLP>$>BU7LP>H""\J)3>R+1?3!X`6+3?3!Z1L+P8M5\#-5[#-5
MY(M-Z`/(`]&+1?R+"(V4"J'KV6Z)5?B+1?R#P`2)1?R+3?#!X1Z+5?#!Z@(+
MRHE-\(M%^,'@!8M-^,'I&PO!BU7T,U7P,U7LBTWD`\@#T8M%_(L(C90*H>O9
M;HE5Z(M%_(/`!(E%_(M-],'A'HM5],'J`@O*B4WTBT7HP>`%BTWHP>D;"\&+
M5?@S5?0S5?"+3>P#R`/1BT7\BPB-E`JAZ]ENB57DBT7\@\`$B47\BTWXP>$>
MBU7XP>H""\J)3?B+1>3!X`6+3>3!Z1L+P8M5Z#-5^#-5](M-\`/(`]&+1?R+
M"(V4"J'KV6Z)5>R+1?R#P`2)1?R+3>C!X1Z+5>C!Z@(+RHE-Z(M%[,'@!8M-
M[,'I&PO!BU7D,U7H,U7XBTWT`\@#T8M%_(L(C90*H>O9;HE5\(M%_(/`!(E%
M_(M-Y,'A'HM5Y,'J`@O*B4WDBT7PP>`%BTWPP>D;"\&+5>PS5>0S5>B+3?@#
MR`/1BT7\BPB-E`JAZ]ENB57TBT7\@\`$B47\BTWLP>$>BU7LP>H""\J)3>R+
M1?3!X`6+3?3!Z1L+P8M5\#-5[#-5Y(M-Z`/(`]&+1?R+"(V4"J'KV6Z)5?B+
M1?R#P`2)1?R+3?#!X1Z+5?#!Z@(+RHE-\(M%^,'@!8M-^,'I&PO!BU7T,U7P
M,U7LBTWD`\@#T8M%_(L(C90*H>O9;HE5Z(M%_(/`!(E%_(M-],'A'HM5],'J
M`@O*B4WTBT7HP>`%BTWHP>D;"\&+5?@S5?0S5?"+3>P#R`/1BT7\BPB-E`JA
MZ]ENB57DBT7\@\`$B47\BTWXP>$>BU7XP>H""\J)3?B+1>3!X`6+3>3!Z1L+
MP8M5Z#-5^#-5](M-\`/(`]&+1?R+"(V4"J'KV6Z)5>R+1?R#P`2)1?R+3>C!
MX1Z+5>C!Z@(+RHE-Z(M%[,'@!8M-[,'I&PO!BU7D,U7H,U7XBTWT`\@#T8M%
M_(L(C90*H>O9;HE5\(M%_(/`!(E%_(M-Y,'A'HM5Y,'J`@O*B4WDBT7PP>`%
MBTWPP>D;"\&+5>PC5>2+3>PC3>@+T8M-Y"--Z`O1BTWX`\@#T8M%_(L(C90*
MW+P;CXE5](M%_(/`!(E%_(M-[,'A'HM5[,'J`@O*B4WLBT7TP>`%BTWTP>D;
M"\&+5?`C5>R+3?`C3>0+T8M-["--Y`O1BTWH`\@#T8M%_(L(C90*W+P;CXE5
M^(M%_(/`!(E%_(M-\,'A'HM5\,'J`@O*B4WPBT7XP>`%BTWXP>D;"\&+5?0C
M5?"+3?0C3>P+T8M-\"--[`O1BTWD`\@#T8M%_(L(C90*W+P;CXE5Z(M%_(/`
M!(E%_(M-],'A'HM5],'J`@O*B4WTBT7HP>`%BTWHP>D;"\&+5?@C5?2+3?@C
M3?`+T8M-]"--\`O1BTWL`\@#T8M%_(L(C90*W+P;CXE5Y(M%_(/`!(E%_(M-
M^,'A'HM5^,'J`@O*B4WXBT7DP>`%BTWDP>D;"\&+5>@C5?B+3>@C3?0+T8M-
M^"--]`O1BTWP`\@#T8M%_(L(C90*W+P;CXE5[(M%_(/`!(E%_(M-Z,'A'HM5
MZ,'J`@O*B4WHBT7LP>`%BTWLP>D;"\&+5>0C5>B+3>0C3?@+T8M-Z"--^`O1
MBTWT`\@#T8M%_(L(C90*W+P;CXE5\(M%_(/`!(E%_(M-Y,'A'HM5Y,'J`@O*
MB4WDBT7PP>`%BTWPP>D;"\&+5>PC5>2+3>PC3>@+T8M-Y"--Z`O1BTWX`\@#
MT8M%_(L(C90*W+P;CXE5](M%_(/`!(E%_(M-[,'A'HM5[,'J`@O*B4WLBT7T
MP>`%BTWTP>D;"\&+5?`C5>R+3?`C3>0+T8M-["--Y`O1BTWH`\@#T8M%_(L(
MC90*W+P;CXE5^(M%_(/`!(E%_(M-\,'A'HM5\,'J`@O*B4WPBT7XP>`%BTWX
MP>D;"\&+5?0C5?"+3?0C3>P+T8M-\"--[`O1BTWD`\@#T8M%_(L(C90*W+P;
MCXE5Z(M%_(/`!(E%_(M-],'A'HM5],'J`@O*B4WTBT7HP>`%BTWHP>D;"\&+
M5?@C5?2+3?@C3?`+T8M-]"--\`O1BTWL`\@#T8M%_(L(C90*W+P;CXE5Y(M%
M_(/`!(E%_(M-^,'A'HM5^,'J`@O*B4WXBT7DP>`%BTWDP>D;"\&+5>@C5?B+
M3>@C3?0+T8M-^"--]`O1BTWP`\@#T8M%_(L(C90*W+P;CXE5[(M%_(/`!(E%
M_(M-Z,'A'HM5Z,'J`@O*B4WHBT7LP>`%BTWLP>D;"\&+5>0C5>B+3>0C3?@+
MT8M-Z"--^`O1BTWT`\@#T8M%_(L(C90*W+P;CXE5\(M%_(/`!(E%_(M-Y,'A
M'HM5Y,'J`@O*B4WDBT7PP>`%BTWPP>D;"\&+5>PC5>2+3>PC3>@+T8M-Y"--
MZ`O1BTWX`\@#T8M%_(L(C90*W+P;CXE5](M%_(/`!(E%_(M-[,'A'HM5[,'J
M`@O*B4WLBT7TP>`%BTWTP>D;"\&+5?`C5>R+3?`C3>0+T8M-["--Y`O1BTWH
M`\@#T8M%_(L(C90*W+P;CXE5^(M%_(/`!(E%_(M-\,'A'HM5\,'J`@O*B4WP
MBT7XP>`%BTWXP>D;"\&+5?0C5?"+3?0C3>P+T8M-\"--[`O1BTWD`\@#T8M%
M_(L(C90*W+P;CXE5Z(M%_(/`!(E%_(M-],'A'HM5],'J`@O*B4WTBT7HP>`%
MBTWHP>D;"\&+5?@C5?2+3?@C3?`+T8M-]"--\`O1BTWL`\@#T8M%_(L(C90*
MW+P;CXE5Y(M%_(/`!(E%_(M-^,'A'HM5^,'J`@O*B4WXBT7DP>`%BTWDP>D;
M"\&+5>@C5?B+3>@C3?0+T8M-^"--]`O1BTWP`\@#T8M%_(L(C90*W+P;CXE5
M[(M%_(/`!(E%_(M-Z,'A'HM5Z,'J`@O*B4WHBT7LP>`%BTWLP>D;"\&+5>0C
M5>B+3>0C3?@+T8M-Z"--^`O1BTWT`\@#T8M%_(L(C90*W+P;CXE5\(M%_(/`
M!(E%_(M-Y,'A'HM5Y,'J`@O*B4WDBT7PP>`%BTWPP>D;"\&+5>PC5>2+3>PC
M3>@+T8M-Y"--Z`O1BTWX`\@#T8M%_(L(C90*W+P;CXE5](M%_(/`!(E%_(M-
M[,'A'HM5[,'J`@O*B4WLBT7TP>`%BTWTP>D;"\&+5?`C5>R+3?`C3>0+T8M-
M["--Y`O1BTWH`\@#T8M%_(L(C90*W+P;CXE5^(M%_(/`!(E%_(M-\,'A'HM5
M\,'J`@O*B4WPBT7XP>`%BTWXP>D;"\&+5?0S5?`S5>R+3>0#R`/1BT7\BPB-
ME`K6P6+*B57HBT7\@\`$B47\BTWTP>$>BU7TP>H""\J)3?2+1>C!X`6+3>C!
MZ1L+P8M5^#-5]#-5\(M-[`/(`]&+1?R+"(V4"M;!8LJ)5>2+1?R#P`2)1?R+
M3?C!X1Z+5?C!Z@(+RHE-^(M%Y,'@!8M-Y,'I&PO!BU7H,U7X,U7TBTWP`\@#
MT8M%_(L(C90*UL%BRHE5[(M%_(/`!(E%_(M-Z,'A'HM5Z,'J`@O*B4WHBT7L
MP>`%BTWLP>D;"\&+5>0S5>@S5?B+3?0#R`/1BT7\BPB-E`K6P6+*B57PBT7\
M@\`$B47\BTWDP>$>BU7DP>H""\J)3>2+1?#!X`6+3?#!Z1L+P8M5[#-5Y#-5
MZ(M-^`/(`]&+1?R+"(V4"M;!8LJ)5?2+1?R#P`2)1?R+3>S!X1Z+5>S!Z@(+
MRHE-[(M%],'@!8M-],'I&PO!BU7P,U7L,U7DBTWH`\@#T8M%_(L(C90*UL%B
MRHE5^(M%_(/`!(E%_(M-\,'A'HM5\,'J`@O*B4WPBT7XP>`%BTWXP>D;"\&+
M5?0S5?`S5>R+3>0#R`/1BT7\BPB-E`K6P6+*B57HBT7\@\`$B47\BTWTP>$>
MBU7TP>H""\J)3?2+1>C!X`6+3>C!Z1L+P8M5^#-5]#-5\(M-[`/(`]&+1?R+
M"(V4"M;!8LJ)5>2+1?R#P`2)1?R+3?C!X1Z+5?C!Z@(+RHE-^(M%Y,'@!8M-
MY,'I&PO!BU7H,U7X,U7TBTWP`\@#T8M%_(L(C90*UL%BRHE5[(M%_(/`!(E%
M_(M-Z,'A'HM5Z,'J`@O*B4WHBT7LP>`%BTWLP>D;"\&+5>0S5>@S5?B+3?0#
MR`/1BT7\BPB-E`K6P6+*B57PBT7\@\`$B47\BTWDP>$>BU7DP>H""\J)3>2+
M1?#!X`6+3?#!Z1L+P8M5[#-5Y#-5Z(M-^`/(`]&+1?R+"(V4"M;!8LJ)5?2+
M1?R#P`2)1?R+3>S!X1Z+5>S!Z@(+RHE-[(M%],'@!8M-],'I&PO!BU7P,U7L
M,U7DBTWH`\@#T8M%_(L(C90*UL%BRHE5^(M%_(/`!(E%_(M-\,'A'HM5\,'J
M`@O*B4WPBT7XP>`%BTWXP>D;"\&+5?0S5?`S5>R+3>0#R`/1BT7\BPB-E`K6
MP6+*B57HBT7\@\`$B47\BTWTP>$>BU7TP>H""\J)3?2+1>C!X`6+3>C!Z1L+
MP8M5^#-5]#-5\(M-[`/(`]&+1?R+"(V4"M;!8LJ)5>2+1?R#P`2)1?R+3?C!
MX1Z+5?C!Z@(+RHE-^(M%Y,'@!8M-Y,'I&PO!BU7H,U7X,U7TBTWP`\@#T8M%
M_(L(C90*UL%BRHE5[(M%_(/`!(E%_(M-Z,'A'HM5Z,'J`@O*B4WHBT7LP>`%
MBTWLP>D;"\&+5>0S5>@S5?B+3?0#R`/1BT7\BPB-E`K6P6+*B57PBT7\@\`$
MB47\BTWDP>$>BU7DP>H""\J)3>2+1?#!X`6+3?#!Z1L+P8M5[#-5Y#-5Z(M-
M^`/(`]&+1?R+"(V4"M;!8LJ)5?2+1?R#P`2)1?R+3>S!X1Z+5>S!Z@(+RHE-
M[(M%],'@!8M-],'I&PO!BU7P,U7L,U7DBTWH`\@#T8M%_(L(C90*UL%BRHE5
M^(M%_(/`!(E%_(M-\,'A'HM5\,'J`@O*B4WPBT7XP>`%BTWXP>D;"\&+5?0S
M5?`S5>R+3>0#R`/1BT7\BPB-E`K6P6+*B57HBT7\@\`$B47\BTWTP>$>BU7T
MP>H""\J)3?2+1>C!X`6+3>C!Z1L+P8M5^#-5]#-5\(M-[`/(`]&+1?R+"(V4
M"M;!8LJ)5>2+1?R#P`2)1?R+3?C!X1Z+5?C!Z@(+RHE-^(M%"(L(`TWDBU4(
MB0J+10B+2`0#3>B+50B)2@2+10B+2`@#3?B+50B)2@B+10B+2`P#3?2+50B)
M2@R+10B+2!`#3?"+50B)2A"+Y5W#58OL@^P,BT4,BT@4B4WXBU4,BT(8B47T
MBTWXP>D#@^$_B4W\BU4,`U7\QD(<@(M%_(/``8E%_(-]_#A^/[E`````*TW\
M46H`BU7\BT4,C4P0'%'HJPX``(/$#(M5#%+H..;__X/$!&HX:@"+10R#P!Q0
MZ(P.``"#Q`SK'KDX````*TW\46H`BU7\BT4,C4P0'%'H;`X``(/$#(M5],'J
M&('B_P```(M%#(A05(M-],'I$('A_P```(M5#(A*58M%],'H""7_````BTT,
MB$%6BU7T@>+_````BT4,B%!7BTWXP>D8@>'_````BU4,B$I8BT7XP>@0)?\`
M``"+30R(05F+5?C!Z@B!XO\```"+10R(4%J+3?B!X?\```"+50R(2EN+10Q0
MBTT(4>@'````@\0(B^5=PU6+[(M%#%#H6N7__X/$!(M-#(L1P>H8@>+_````
MBT4(B!"+30R+$<'J$('B_P```(M%"(A0`8M-#(L1P>H(@>+_````BT4(B%`"
MBTT,BQ&!XO\```"+10B(4`.+30R+403!ZAB!XO\```"+10B(4`2+30R+403!
MZA"!XO\```"+10B(4`6+30R+403!Z@B!XO\```"+10B(4`:+30R+402!XO\`
M``"+10B(4`>+30R+40C!ZAB!XO\```"+10B(4`B+30R+40C!ZA"!XO\```"+
M10B(4`F+30R+40C!Z@B!XO\```"+10B(4`J+30R+40B!XO\```"+10B(4`N+
M30R+40S!ZAB!XO\```"+10B(4`R+30R+40S!ZA"!XO\```"+10B(4`V+30R+
M40S!Z@B!XO\```"+10B(4`Z+30R+40R!XO\```"+10B(4`^+30R+41#!ZAB!
MXO\```"+10B(4!"+30R+41#!ZA"!XO\```"+10B(4!&+30R+41#!Z@B!XO\`
M``"+10B(4!*+30R+41"!XO\```"+10B(4!-=PU6+[%'H^0H``%#H!0L``(/$
M!%"+10A0Z.8*``!0Z.P*``"#Q`2+"%'HU0H``%#HVPH``(/$!(L0_U)0@\0,
MA<!U8>B["@``4.C'"@``@\0$,\EFBT@&@>$`\```@?D`0```=`8STH72=#EJ
M`HM%"%#HC0H``%#HDPH``(/$!(L(4>A\"@``4.B""@``@\0$BQ#_$H/$#(7`
M=0G'1?P!````ZP?'1?P`````BT7\B^5=PU6+[(/L"(M%"%#H.-'__X/$!(E%
M_(M-_%'HW=#__X/$!(E%^.AFU/__A<!T.8-]"`!T,XM5"%+H_PH``(/$!(7`
M="-H6-1``(M%^%#_%8Q@0`"#Q`@[1?AU#(M-"%'H!P```(/$!(OE7<-5B^R!
M[#`!``#'A=#^__\`````@WT(`'00BT4(4.BO"@``@\0$A<!U!>G'`0``BTT(
M4>B:"@``@\0$!0(!``")1?B+5?A2Z)P)``!0Z*X)``"#Q`2+`%#HBPD``%#H
MG0D``(/$!(L(_Q&#Q`B)1?R+50A2:&#40`"+1?Q0_Q6<8$``@\0,C8W8_O__
M48M5_%+_%4A@0`"#Q`B)A=3^__^#O=3^____=07I2`$``&AHU$``C87L_O__
M4/\5C&!``(/$"(7`=1^-C>S^__]1BU4(4FALU$``BT7\4/\5G&!``(/$$.L9
MC8WL_O__46ATU$``BU7\4O\5G&!``(/$#&AXU$``BT7\4/\5C&!``(/$"(E%
M\(-]\`!T+FA\U$``BTWP4>BD"0``@\0(A<`/A(<```!H@-1``(M5\%+HBPD`
M`(/$"(7`='*+A=C^__^#X!"%P'0.BTW\4>BC_O__@\0$ZU>-E>S^__]2_Q40
M8$``B47TQX70_O__`````(M%_%#_%4Q@0`"#Q`2%P'0LBXW0_O__BY70_O__
M@\(!B970_O__@_D*?1*#??0`=`J+1?10_Q4,8$``Z\.-C=C^__]1BY74_O__
M4O\54&!``(/$"(7`#X35_O__BX74_O__4/\55&!``(/$!(M-"%'_%5A@0`"#
MQ`2+Y5W#58OL:O_HY`<``%#H"`@``(/$"&H`:.A'0`#HSP<``%#H[0<``(/$
M#%W#58OL@^P(5NBX!P``4.@&"```@\0$B_#HJ`<``%#H\`<``(/$!(L`BT@$
MBA:(41CHD`<``%#HT@<``(/$!(L`BW`0@>;_`0``Z'<'``!0Z+\'``"#Q`2+
M"(M1!&:)<AJXK-E``(7`=!IJ`&BPV4``Z%`'``!0Z(P'``"#Q`R)1?SK!\=%
M_`````#H-@<``%#H?@<``(/$!(L(BU$$BT7\B4(<Z!T'``!0Z%,'``"#Q`2+
M\.@-!P``4.A5!P``@\0$BPB+402+!HE"(.CU!@``4.@E!P``@\0$@S@`=!CH
MX@8``%#H$@<``(/$!(L(BU%LB57XZP?'1?@`````Z,,&``!0Z`L'``"#Q`2+
M`(M(!(M5^(E1).BJ!@``4.CR!@``@\0$BP"+2`3'02@`````Z)`&``!0Z-@&
M``"#Q`2+$(M"!,=`+`````#H=@8``%#HH`8``(/$!(OPZ&8&``!0Z*X&``"#
MQ`2+"(M1!(L&B4(P,\F%R0^%C/[__UZ+Y5W#58OL@^PDQT7D`````.@R!@``
M4.B\!@``@\0$Q@`!:(340`#H0,G__X/$!(E%_(-]_`!T%HM%_`^^"(/Y,74+
MBU7\#[Y"`87`=`7H"\[__VH+:@%HE-1``.CG!0``4.AK!@``@\00B47T@WWT
M``^$_@```(M-](M1#(M"&(E%Z,=%[`$```#K"8M-[(/!`8E-[(M5[#L5?-E`
M``^-D````&H`BT7L@^@!4(M-Z%'HD@4``%#H$`8``(/$$(E%\(-]\`!U`NMJ
MBU7PBP*+2`B!X0`$``"!^0`$``!U#8M5\(L"BT@,B4W<ZQMJ`FH`BU7PBP)0
MZ$P%``!0Z,0%``"#Q!")1=R+3=Q1BU7LH8#90`"+#)!1Z`\&``"#Q`B%P'0"
MZPZ+5>2#P@&)5>3I6/___Z%\V4``@^@!.47D=33'1>P!````ZPF+3>R#P0&)
M3>R+5>P[%7S90`!]%XM%Z%#HX00``%#H4P4``(/$"(E%^.O5:@5J`6B<U$``
MZ,4$``!0Z$D%``"#Q!")1?2#??0`=$YHH-1``(M-](M1#(L"4.B@!```4.@,
M!0``@\0,BTWTBU$,BP*+2`B!X0``0`"%R707BU7TBT(,BPA1Z'0$``!0Z-H$
M``"#Q`@STH72=<YJ!6H!:*S40`#H5P0``%#HVP0``(/$$(E%](-]]``/A+``
M``#'1>``````:+#40`#H5,?__X/$!(E%X(-]X`!T'8M%X%"+3?2+40R+`E#H
M$@0``%#H?@0``(/$#.MVZ)W$__^)1>"#?>``=$B+3>!1BU7TBT(,BPA1Z.<#
M``!0Z%,$``"#Q`R+5>!2Z-4#``!0Z.<#``"#Q`2+`%#HQ`,``%#HU@,``(/$
M!(L(_U$(@\0(ZR"+%8#90`"+`E"+3?2+40R+`E#HF@,``%#H!@0``(/$#.B,
M`P``4.@6!```@\0$Q@``Z'L#``!0Z-L#``"#Q`3'``````!HP-1``.B&QO__
M@\0$HWC50`"#/7C50```=12+#8#90`!1Z$[/__^#Q`2C>-5``&CM`0``BQ5X
MU4``4N@L`P``4.B&`P``@\0$BP!0Z!L#``!0Z'4#``"#Q`2+"/\1@\0,B47L
M@WWL`'0L@WWL$70F@WWL_W0@BU7L4J%XU4``4(L-@-E``(L14FC,U$``Z#,#
M``"#Q!"+Y5W#58OL@^P<5L=%]`````"-11!0C4T,48U5"%+HBP,``(/$#&H`
MZ'L#``"#Q`0/O@"%P'5;Z&8#``"C=-5``(,]=-5```!U*6H!Z(4"``!0Z)T"
M``"#Q`2+"%'H=`(``%#HC`(``(/$!(L0_U((@\0(H7350`!0Z!X#``"#Q`3H
M4`(``%#H"@,``(/$!,8``.@_`@``4.CS`@``@\0$B47PBTWPBA&`R@*+1?"(
M$.@A`@``4.C5`@``@\0$B47LBTWLBA&`R@&+1>R($+D!````A<ET.8M5"(/"
M!8E5Y,=%Z`````#?;>3<!8AA0`#<'8!A0`#?X/;$0743H<Q@0`!0:!S50`#H
M(P(``(/$"(M5"(T$E10```!0Z&H"``"#Q`2C@-E``(M-](L5@-E``(M%#(L`
MB02*BTWT@\$!B4WTBU7TH8#90`#'!)`@U4``BTWT@\$!B4WTBU7TH8#90`#'
M!)"084``BTWT@\$!B4WTBU7TH8#90`#'!)`DU4``BTWT@\$!B4WTBU7TB15\
MV4``QT7X`0```.L)BT7X@\`!B47XBTWX.TT(?1V+5?@#%7S90`"A@-E``(M-
M^(MU#(L,CHE,D/SKTHM5"`,5?-E``*&`V4``QT20_`````!J`(L-@-E``%&+
M%7S90`"+10B-3!#_46AI3T``BQ5TU4``4NA\`0``@\04B47\@WW\`'41H735
M0`!0Z%\!``"#Q`2)1?R+#7350`!1Z$<!``"#Q`1H*-5``.B\P___@\0$A<!U
M,X,]>-5```!U$F@TU4``Z*+#__^#Q`2C>-5``(,]>-5```!T#XL5>-5``%+H
M$/;__X/$!*%TU4``4.CO````@\0$Z.$```"+1?Q>B^5=PU6+[.@[````4.B)
MP/__@\0$:@!HM-E``&BXV4``:&A)0`!H0-5``.@7````4.CO````@\087</_
M)5!A0`#_)4QA0`#_)4AA0`#_)41A0`#_)4!A0`#_)3QA0`#_)3AA0`#_)31A
M0`#_)3!A0`#_)2QA0`#_)2AA0`#_)21A0`#_)2!A0`#_)1QA0`#_)1AA0`#_
M)11A0`#_)1!A0`#_)0QA0`#_)0AA0`#_)01A0`#_)0!A0`#_)?Q@0`#_)?A@
M0`#_)?1@0`#_)?!@0`#_)>Q@0`#_)>A@0`#_)>1@0`#_)>!@0`#_)=Q@0`#_
M)=A@0`#_)=1@0`#_)=!@0`#_)<A@0`#_)<1@0`#_)<!@0`#_);Q@0`#_);A@
M0`#_);1@0`#_);!@0`#_)9A@0`#_)9!@0`#,S,S,43T`$```C4PD"'(4@>D`
M$```+0`0``"%`3T`$```<^PKR(O$A0&+X8L(BT`$4,/,_R5@8$``_R6H8$``
MS,S,S%6+[&K_:("]0`!H$E)``&2A`````%!DB24`````@^P@4U97B67H@V7\
M`&H!_Q5<8$``68,-S-E``/^##=#90`#__Q488$``BPW(V4``B0C_%1Q@0`"+
M#<390`")"*$@8$``BP"CU-E``.C#````@SUPU4```'4,:`Y20`#_%21@0`!9
MZ)0```!H#-!``&@(T$``Z'\```"AP-E``(E%V(U%V%#_-;S90`"-1>!0C474
M4(U%Y%#_%2Q@0`!H!-!``&@`T$``Z$P```#_%3!@0`"+3>")"/]UX/]UU/]U
MY.@7^___@\0PB47<4/\5-&!``(M%[(L(BPF)3=!04>@/````65G#BV7H_W70
M_Q4\8$``_R4X8$``_R4H8$``:````P!H```!`.@-````65G#,\##P_\EH&!`
M`/\EI&!`````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````DL(```````!,P@``8L(``'#"````````1L0``#;$```FQ```$L0`
M``;$``#VPP``YL,``-[#``#0PP``R,,``+##``"FPP``F,,``([#``""PP``
M=,,``&K#``!4Q```5L,``$;#```ZPP``,,,``";#```:PP``$,,```;#``#\
MP@``\L(``.+"``#8P@``SL(``,3"``"ZP@``L,(``&;$``!ZQ```8,,`````
M```LP@``&L(```3"``#VP0``Y,$``,3!``"LP0``FL$``(3!``!VP0``:L$`
M`%K!``!.P0``/L$``"K!```8P0``",$``/3```#DP```U,```,;```"RP```
MHL```(K```!VP```7,```$S````\P```)L```!+```#^OP``[K\``-2_``#"
MOP``LK\``)Z_``".OP``?+\``&B_``!:OP``2+\`````````````````````
M``!GO)-,``````(```!%`````````````0````````"`____ST$`````````
M`",A+W5S<B]B:6XO<&5R;`IE=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3
M("0P("1[,2LB)$`B?2<*("`@(&EF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`H*<&%C:V%G92!?7W!A<E]P;#L*"B,@+2TM(%1H:7,@<V-R
M:7!T(&UU<W0@;F]T('5S92!A;GD@;6]D=6QE<R!A="!C;VUP:6QE('1I;64@
M+2TM"B,@=7-E('-T<FEC=#L*"B-L:6YE(#$U.`H*;7D@*"1P87)?=&5M<"P@
M)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!
M3GTI('L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*("`@(')E<75I<F4@1FEL
M93HZ0F%S96YA;64["B`@("!R97%U:7)E($9I;&4Z.E-P96,["B`@("!M>2`D
M=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*
M("`@(&]U=',H<7%[4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*
M("`@($9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PH@("`@<FUD:7(@)'!A<E]T96UP
M.PH@("`@(R!$;VXG="!R96UO=F4@=&]P9&ER(&)E8V%U<V4@=&AI<R!C875S
M97,@82!R86-E('=I=&@@;W1H97(@87!P<PH@("`@(R!T:&%T(&%R92!T<GEI
M;F<@=&\@<W1A<G0N"@H@("`@:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@
M)TU35VEN,S(G*2!["B`@("`@("`@(R!3;VUE=&AI;F<@=V5N="!W<F]N9R!U
M;FQI;FMI;F<@=&AE('1E;7!O<F%R>2!D:7)E8W1O<GDN("!4:&ES"B`@("`@
M("`@(R!T>7!I8V%L;'D@:&%P<&5N<R!O;B!P;&%T9F]R;7,@=&AA="!D:7-A
M;&QO=R!U;FQI;FMI;F<@<VAA<F5D"B`@("`@("`@(R!L:6)R87)I97,@86YD
M(&5X96-U=&%B;&5S('1H870@87)E(&EN('5S92X@56YL:6YK('=I=&@@82!B
M86-K9W)O=6YD"B`@("`@("`@(R!S:&5L;"!C;VUM86YD('-O('1H92!F:6QE
M<R!A<F4@;F\@;&]N9V5R(&EN('5S92!B>2!T:&ES('!R;V-E<W,N"B`@("`@
M("`@(R!$;VXG="!D;R!A;GET:&EN9R!O;B!7:6YD;W=S(&)E8V%U<V4@;W5R
M('!A<F5N="!P<F]C97-S('=I;&P*("`@("`@("`C('1A:V4@8V%R92!O9B!C
M;&5A;FEN9R!T:&EN9W,@=7`N"@H@("`@("`@(&UY("1T;7`@/2!N97<@1FEL
M93HZ5&5M<"@*("`@("`@("`@("`@5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*
M("`@("`@("`@("`@1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T
M;W!D:7(I+`H@("`@("`@("`@("!3549&25@@/3X@)RYC;60G+`H@("`@("`@
M("`@("!53DQ)3DL@/3X@,"P*("`@("`@("`I.PH*("`@("`@("!P<FEN="`D
M=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*
M("`@<FT@+7)F("<D<&%R7W1E;7`G"B`@(&EF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@H@("`@("`@8G)E86L*("`@9FD*("`@<VQE97`@,0H@("!X
M/6!E>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N
M("(G"B(["B`@("`@("`@("`@(&-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64[
M"B`@("`@("`@;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N
M=6QL(#(^)C$@)B<["B`@("`@("`@8VQO<V4@)'1M<#L*("`@("`@("!S>7-T
M96TH)&-M9"D["B`@("`@("`@;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@
M<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("D*("`@("`@("`@("`@("X@
M)'1M<"T^9FEL96YA;64I.PH@("`@?0I]('T*"D)%1TE.('L*("`@($EN=&5R
M;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z
M.D)/3U0["@H@("`@979A;"!["@I?<&%R7VEN:71?96YV*"D["@II9B`H97AI
M<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2![
M"B`@("!`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D
M14Y6>U!!4E]!4D=#?2`M(#$I.PH@("`@)#`@/2`D14Y6>U!!4E]!4D=67S!]
M.PI]"F5L<V4@>PH@("`@9F]R("AK97ES("5%3E8I('L*("`@("`@("!D96QE
M=&4@)$5.5GLD7WT@:68@+UY005)?05)'5E\O.PH@("`@?0I]"@IM>2`D<75I
M970@/2`A)$5.5GM005)?1$5"54=].PH*(R!F:7@@)'!R;V=N86UE(&EF(&EN
M=F]K960@9G)O;2!0051("FUY("5#;VYF:6<@/2`H"B`@("!P871H7W-E<"`@
M("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*("`@(%]E>&4@
M("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G
M+F5X92<@.B`G)RDL"B`@("!?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7
M:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PH*7W-E=%]P<F]G;F%M92@I.PI?
M<V5T7W!A<E]T96UP*"D["@HC($UA9VEC('-T<FEN9R!C:&5C:VEN9R!A;F0@
M97AT<F%C=&EN9R!B=6YD;&5D(&UO9'5L97,@>WM["FUY("@D<W1A<G1?<&]S
M+"`D9&%T85]P;W,I.PI["B`@("!L;V-A;"`D4TE'>U]?5T%23E]??2`]('-U
M8B![?3L*"B`@("`C($-H96-K(&9I;&4@='EP92P@9V5T('-T87)T(&]F(&1A
M=&$@<V5C=&EO;B![>WL*("`@(&]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O
M<B!L87-T.PH@("`@8FEN;6]D92A?1D@I.PH*("`@(&UY("1B=68["B`@("!S
M965K(%]&2"P@+3@L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@.#L*("`@(&QA
M<W0@=6YL97-S("1B=68@97$@(EQN4$%2+G!M7&XB.PH*("`@('-E96L@7T9(
M+"`M,3(L(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@('-E96L@7T9(
M+"`M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*("`@(')E860@7T9(+"`D
M8G5F+"`T.PH*("`@("1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PH@("`@
M(R!]?7T*"B`@("`C($5X=')A8W1I;F<@96%C:"!F:6QE(&EN=&\@;65M;W)Y
M('M[>PH@("`@;7D@)7)E<75I<F5?;&ES=#L*("`@('=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PH@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@("`@
M(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*"B`@("`@("`@
M;7D@)&9U;&QN86UE(#T@)&)U9CL*("`@("`@("!O=71S*'%Q*%5N<&%C:VEN
M9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["B`@("`@("`@;7D@)&-R8R`]("@@
M)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E
M9CL*("`@("`@("!M>2`H)&)A<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\
M*#\Z+BHO*3\H+BHI*%PN+BHI?"D["@H@("`@("`@(')E860@7T9(+"`D8G5F
M+"`T.PH@("`@("`@(')E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*"B`@("`@("`@:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN
M*#\Z<&U\<&Q\:7A\86PI)"]I*2!["B`@("`@("`@("`@(&UY("@D;W5T+"`D
M9FEL96YA;64I(#T@7W1E;7!F:6QE*"1E>'0L("1C<F,I.PH@("`@("`@("`@
M("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*
M("`@("`@("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@
M("`@(&-L;W-E("1O=70["B`@("`@("`@("`@("`@("!C:&UO9"`P-S4U+"`D
M9FEL96YA;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PH@("`@("`@
M("`@("`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["B`@("`@("`@?0H@("`@("`@(&5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M("`@("`@("`@("`@(R!S:&]U;&0@8F4@;6]V960@=&\@7W1E;7!F:6QE*"D*
M("`@("`@("`@("`@;7D@)&9I;&5N86UE(#T@(B1%3E9[4$%27U1%35!]+R1B
M87-E;F%M921E>'0B.PH@("`@("`@("`@("!O=71S*")32$Q)0CH@)&9I;&5N
M86UE7&XB*3L*("`@("`@("`@("`@;W!E;B!M>2`D;W5T+"`G/B<L("1F:6QE
M;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@
M("`@("`@("`@('!R:6YT("1O=70@)&)U9CL*("`@("`@("`@("`@8VQO<V4@
M)&]U=#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@("1R
M97%U:7)E7VQI<W1[)&9U;&QN86UE?2`]"B`@("`@("`@("`@("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@>PH@("`@("`@("`@("`@
M("`@8G5F(#T^("1B=68L"B`@("`@("`@("`@("`@("!C<F,@/3X@)&-R8RP*
M("`@("`@("`@("`@("`@(&YA;64@/3X@)&9U;&QN86UE+`H@("`@("`@("`@
M("!].PH@("`@("`@('T*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@
M('T*("`@(",@?7U]"@H@("`@;&]C86P@0$E.0R`]("AS=6(@>PH@("`@("`@
M(&UY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*"B`@("`@("`@<F5T=7)N(&EF
M(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PH*("`@("`@("!M>2`D9FEL96YA
M;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["B`@
M("`@("`@("`@(&UY("1K97D["B`@("`@("`@("`@(&9O<F5A8V@@*&ME>7,@
M)7)E<75I<F5?;&ES="D@>PH@("`@("`@("`@("`@("`@;F5X="!U;FQE<W,@
M+UQ1)&UO9'5L95Q%)"\["B`@("`@("`@("`@("`@("`D:V5Y(#T@)%\[(&QA
M<W0["B`@("`@("`@("`@('T*("`@("`@("`@("`@9&5L971E("1R97%U:7)E
M7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*("`@("`@("!](&]R(')E
M='5R;CL*"B`@("`@("`@)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1F:6QE
M;F%M92\D;6]D=6QE(CL*"B`@("`@("`@:68@*"1%3E9[4$%27T-,14%.?2!A
M;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*("`@("`@("`@("`@;7D@
M)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*("`@("`@
M("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!P<FEN="`D9F@@)&9I
M;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@<V5E:R@D9F@L(#`L(#`I.PH@
M("`@("`@("`@("!R971U<FX@)&9H.PH@("`@("`@('T*("`@("`@("!E;'-E
M('L*("`@("`@("`@("`@;7D@*"1O=70L("1N86UE*2`](%]T96UP9FEL92@G
M+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["B`@("`@("`@("`@(&EF("@D;W5T
M*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@
M("`@("`@<')I;G0@)&]U="`D9FEL96YA;64M/GMB=69].PH@("`@("`@("`@
M("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!O
M<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O<B!D:64@)"$["B`@("`@("`@("`@
M(&)I;FUO9&4H)&9H*3L*("`@("`@("`@("`@<F5T=7)N("1F:#L*("`@("`@
M("!]"@H@("`@("`@(&1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;FYO
M="!F:6YD("1M;V1U;&4A7&XB.PH@("`@?2P@0$E.0RD["@H@("`@(R!.;W<@
M;&]A9"!A;&P@8G5N9&QE9"!F:6QE<R![>WL*"B`@("`C(&EN:71I86QI>F4@
M<VAA<F5D(&]B:F5C="!P<F]C97-S:6YG"B`@("!R97%U:7)E(%A33&]A9&5R
M.PH@("`@<F5Q=6ER92!005(Z.DAE879Y.PH@("`@<F5Q=6ER92!#87)P.CI(
M96%V>3L*("`@(')E<75I<F4@17AP;W)T97(Z.DAE879Y.PH@("`@4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH*("`@(",@;F]W(&QE="=S('1R
M>2!G971T:6YG(&AE;'!E<B!M;V1U;&5S(&9R;VT@=VET:&EN"B`@("!R97%U
M:7)E($E/.CI&:6QE.PH*("`@(",@;&]A9"!R97-T(&]F('1H92!G<F]U<"!I
M;@H@("`@=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I
M<F5?;&ES="E;,%TI('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@
M/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@('5N;&5S
M<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@
M>PH@("`@("`@("`@("`C(')E<75I<F4@;6]D=6QE<RP@9&\@;W1H97(@97AE
M8W5T86)L92!F:6QE<PH@("`@("`@("`@("!I9B`H)&9I;&5N86UE(#U^("]<
M+G!M8S\D+VDI('L*("`@("`@("`@("`@("`@(')E<75I<F4@)&9I;&5N86UE
M.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@
M("`@("`@(R!3:VEP($%C=&EV95-T871E)W,@<VET96-U<W1O;6EZ92YP;"!F
M:6QE.@H@("`@("`@("`@("`@("`@9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL
M96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["B`@("`@("`@("`@('T*
M("`@("`@("!]"B`@("`@("`@9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*("`@('T*"B`@("`C('U]?0H*("`@(&QA<W0@=6YL97-S("1B=68@
M97$@(E!+7#`P,UPP,#0B.PH@("`@)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PI]"B,@?7U]"@HC($%R9W5M96YT('!R;V-E<W-I;F<@>WM["FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PH*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@
M*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"@HD<75I970@/2`P
M('5N;&5S<R`D14Y6>U!!4E]$14)51WT["B,@1&]N)W0@<W=A;&QO=R!A<F=U
M;65N=',@9F]R(&-O;7!I;&5D(&5X96-U=&%B;&5S('=I=&AO=70@+2UP87(M
M;W!T:6]N<PII9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A
M<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*("`@(&UY("5D:7-T7V-M9"`]('%W
M*`H@("`@("`@('`@("!B;&EB7W1O7W!A<@H@("`@("`@(&D@("!I;G-T86QL
M7W!A<@H@("`@("`@('4@("!U;FEN<W1A;&Q?<&%R"B`@("`@("`@<R`@('-I
M9VY?<&%R"B`@("`@("`@=B`@('9E<FEF>5]P87(*("`@("D["@H@("`@(R!I
M9B!T:&4@87!P(&ES(&EN=F]K960@87,@(F%P<&YA;64@+2UP87(M;W!T:6]N
M<R`M+7)E=7-E(%!23T=204T@0%!23T=?05)'5B(L"B`@("`C('5S92!T:&4@
M87!P('1O(')U;B!T:&4@9VEV96X@<&5R;"!C;V1E(&EN<W1E860@;V8@86YY
M=&AI;F<@9G)O;2!T:&4*("`@(",@87!P(&ET<V5L9B`H8G5T('-T:6QL('-E
M="!U<"!T:&4@;F]R;6%L(&%P<"!E;G9I<F]N;65N="!A;F0@0$E.0RD*("`@
M(&EF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["B`@("`@
M("`@<VAI9G0@0$%21U8["B`@("`@("`@)$5.5GM005)?05!07U)%55-%?2`]
M('-H:69T($!!4D=6.PH@("`@?0H@("`@96QS92![(",@;F]R;6%L('!A<FP@
M8F5H879I;W5R"@H@("`@("`@(&UY($!A9&1?=&]?:6YC.PH@("`@("`@('=H
M:6QE("A`05)'5BD@>PH@("`@("`@("`@("`D05)'5ELP72`]?B`O7BTH6T%)
M34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T.PH*("`@("`@("`@("`@:68@
M*"0Q(&5Q("=))RD@>PH@("`@("`@("`@("`@("`@<'5S:"!`861D7W1O7VEN
M8RP@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=-)RD@>PH@("`@("`@("`@("`@("`@979A;"`B=7-E("0R(CL*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T$G*2!["B`@("`@
M("`@("`@("`@("!U;G-H:69T($!P87)?87)G<RP@)#(["B`@("`@("`@("`@
M('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=/)RD@>PH@("`@("`@("`@
M("`@("`@)&]U="`]("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<VEF("@D,2!E<2`G8B<I('L*("`@("`@("`@("`@("`@("1B=6YD;&4@/2`G
M<VET92<["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q
M("=")RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]("=A;&PG.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G<2<I('L*("`@
M("`@("`@("`@("`@("1Q=6EE="`](#$["B`@("`@("`@("`@('T*("`@("`@
M("`@("`@96QS:68@*"0Q(&5Q("=,)RD@>PH@("`@("`@("`@("`@("`@;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L
M;V<Z("0A(CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)U0G*2!["B`@("`@("`@("`@("`@("`D8V%C:&5?;F%M92`]("0R.PH@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!S:&EF="A`05)'5BD["@H@("`@
M("`@("`@("!I9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*("`@("`@
M("`@("`@("`@(&1E;&5T92`D14Y6>R=005)?5$5-4"=].PH@("`@("`@("`@
M("`@("`@:6YI=%]I;F,H*3L*("`@("`@("`@("`@("`@(')E<75I<F4@4$%2
M.CI$:7-T.PH@("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH
M*2!U;FQE<W,@0$%21U8["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PH@("`@("`@("`@("`@("`@97AI=#L*
M("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*("`@('T*?0H*(R!86%@@+2T@861D("TM<&%R+61E
M8G5G('-U<'!O<G0A"@HC('U]?0H*(R!/=71P=70@;6]D92`H+4\I(&AA;F1L
M:6YG('M[>PII9B`H)&]U="D@>PH@("`@>PH@("`@("`@("-L;V-A;"`D24Y#
M>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@
M("`@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@("`@("!R97%U:7)E($%R8VAI
M=F4Z.EII<#L*("`@('T*"B`@("!M>2`D<&%R(#T@<VAI9G0H0$%21U8I.PH@
M("`@;7D@)'II<#L*"@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@
M(&]P96X@;7D@)&9H+"`G/"<L("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G
M)'!A<B<Z("0A(CL*("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*"B`@("`@("`@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PH@("`@("`@("@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE
M*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*("`@("`@
M("`@("`@;W(@9&EE(")296%D("<D<&%R)R!E<G)O<CH@)"$B.PH@("`@?0H*
M"B`@("!M>2`E96YV(#T@9&\@>PH@("`@("`@(&EF("@D>FEP(&%N9"!M>2`D
M;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B`@("`@("`@
M("`@("1M971A(#U^(',O+BI><&%R.B0O+VUS.PH@("`@("`@("`@("`D;65T
M82`]?B!S+UY<4RXJ+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PH@("`@("`@('T*("`@('T["@H@("`@(R!/<&5N
M(&EN<'5T(&%N9"!O=71P=70@9FEL97,@>WM["B`@("!L;V-A;"`D+R`](%PT
M.PH*("`@(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(%!!4BP@
M)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PH@("`@("`@(&)I;FUO9&4H
M4$%2*3L*("`@("`@("!D:64@(B1P87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N
M;&5S<R`\4$%2/B!E<2`B4$M<,#`S7#`P-"(["B`@("!]"@H@("`@0W)E871E
M4&%T:"@D;W5T*2`["B`@("`*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<H
M"B`@("`@("`@)&]U="P*("`@("`@("!)3SHZ1FEL93HZ3U]#4D5!5"@I('P@
M24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`H@
M("`@("`@(#`W-S<L"B`@("`I(&]R(&1I92`D(3L*("`@(&)I;FUO9&4H)&9H
M*3L*"B`@("`D+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S
M(#H@=6YD968["B`@("!S965K(%]&2"P@,"P@,#L*("`@(&UY("1L;V%D97(@
M/2!S8V%L87(@/%]&2#X["B`@("!I9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*("`@("`@("!R97%U
M:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*("`@("`@("!005(Z.D9I;'1E
M<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0H@("`@?0H@
M("`@9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PH@("`@("`@
M(&UY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0["B`@("`@("`@)'9A;"`]
M(&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["B`@("`@("`@;7D@)&UA
M9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@+B`B7U\B.PH@("`@("`@
M(&UY("1S970@/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B`@("`@
M("`@)&QO861E<B`]?B!S>R1M86=I8R@@*RE]>PH@("`@("`@("`@("`D;6%G
M:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I
M*2D*("`@("`@("!]96<["B`@("!]"B`@("`D9F@M/G!R:6YT*"1L;V%D97(I
M.PH@("`@)"\@/2!U;F1E9CL*("`@(",@?7U]"@H@("`@(R!7<FET92!B=6YD
M;&5D(&UO9'5L97,@>WM["B`@("!I9B`H)&)U;F1L92D@>PH@("`@("`@(')E
M<75I<F4@4$%2.CI(96%V>3L*("`@("`@("!005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["B`@("`@("`@:6YI=%]I;F,H*3L*"B`@("`@("`@<F5Q
M=6ER95]M;V1U;&5S*"D["@H@("`@("`@(&UY($!I;F,@/2!S;W)T('L*("`@
M("`@("`@("`@;&5N9W1H*"1B*2`\/3X@;&5N9W1H*"1A*0H@("`@("`@('T@
M9W)E<"!["B`@("`@("`@("`@("$O0E-$4$%.+PH@("`@("`@('T@9W)E<"![
M"B`@("`@("`@("`@("@D8G5N9&QE(&YE("=S:71E)RD@;W(*("`@("`@("`@
M("`@*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*("`@
M("`@("`@("`@("1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"B`@("`@("`@?2!`24Y#.PH*("`@("`@("`C($9I;&4@97AI<W1S('1E<W0@
M861D960@=&\@9FEX(%)4(",T,3<Y,#H*("`@("`@("`C($9U;FYY+"!N;VXM
M97AI<W1I;F<@96YT<GD@:6X@7SPN+BXN875T;R]#;VUP<F5S<R]287<O6FQI
M8B]A=71O<W!L:70N:7@N"B`@("`@("`@(R!4:&ES(&ES(&$@8F%N9"UA:60@
M9FEX('=I=&@@;F\@9&5E<&5R(&=R87-P(&]F('1H92!I<W-U92X*("`@("`@
M("`C(%-O;65B;V1Y('!L96%S92!G;R!T:')O=6=H('1H92!P86EN(&]F('5N
M9&5R<W1A;F1I;F<@=VAA="=S(&AA<'!E;FEN9RP*("`@("`@("`C($D@9F%I
M;&5D+B`M+2!3=&5F9F5N"B`@("`@("`@;7D@)69I;&5S.PH@("`@("`@("]>
M7SPH+BLI)"\@86YD("UE("0Q(&%N9"`D9FEL97-[)#%]*RL@9F]R(&ME>7,@
M)3HZ.PH@("`@("`@("1F:6QE<WLD7WTK*R!F;W(@=F%L=65S("5)3D,["@H@
M("`@("`@(&UY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.PH@("`@("`@(&UY("5W<FET=&5N.PH*("`@("`@("!F;W)E86-H("AS;W)T
M(&ME>7,@)69I;&5S*2!["B`@("`@("`@("`@(&UY("@D;F%M92P@)&9I;&4I
M.PH*("`@("`@("`@("`@9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["B`@("`@
M("`@("`@("`@("!I9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1??2D@>PH@("`@("`@("`@("`@("`@("`@("1F:6QE(#T@)%\["B`@("`@
M("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@('T*("`@("`@
M("`@("`@("`@(&5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI
M('L*("`@("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D,2P@
M)#(I.PH@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H;2%>+VQO861E<B];7B]=*R\H
M+BI;7D-C72E<6B$I('L*("`@("`@("`@("`@("`@("`@("!I9B`H;7D@)')E
M9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD,7TI('L*("`@("`@("`@
M("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PH@
M("`@("`@("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@("`@("!E;'-I9B`H+68@(B1D:7(O)#$B
M*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@
M*"(D9&ER+R0Q(BP@)#$I.PH@("`@("`@("`@("`@("`@("`@("`@("!L87-T
M.PH@("`@("`@("`@("`@("`@("`@('T*("`@("`@("`@("`@("`@('T*("`@
M("`@("`@("`@?0H*("`@("`@("`@("`@;F5X="!U;FQE<W,@9&5F:6YE9"`D
M;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PH@("`@("`@("`@("!N
M97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT
M7$4D+SL*("`@("`@("`@("`@;W5T<R@@:F]I;B`B(BP*("`@("`@("`@("`@
M("`@('%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92P*("`@("`@("`@("`@("`@('%Q*"(N+BXI"B`@("`@("`@("`@
M("D["@H@("`@("`@("`@("!M>2`D8V]N=&5N=#L*("`@("`@("`@("`@:68@
M*')E9B@D9FEL92DI('L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<V4@>PH@
M("`@("`@("`@("`@("`@;W!E;B!&24Q%+"`G/"<L("1F:6QE(&]R(&1I92`B
M0V%N)W0@;W!E;B`D9FEL93H@)"$B.PH@("`@("`@("`@("`@("`@8FEN;6]D
M92A&24Q%*3L*("`@("`@("`@("`@("`@("1C;VYT96YT(#T@/$9)3$4^.PH@
M("`@("`@("`@("`@("`@8VQO<V4@1DE,13L*"B`@("`@("`@("`@("`@("!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92D*("`@("`@("`@("`@("`@("`@("!I9B`A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["@H@("`@("`@
M("`@("`@("`@(R!$;R!N;W0@;&5T(%A33&]A9&5R('!I8VL@=7`@875T;R\J
M(&9R;VT@96YV:7)O;FUE;G0*("`@("`@("`@("`@("`@("1C;VYT96YT(#U^
M(',O9V]T;R`K<F5T<GD@*W5N;&5S<R`K+BHO9V]T;R!R971R>3LO"B`@("`@
M("`@("`@("`@("`@("`@:68@;&,H)&YA;64I(&5Q(&QC*")84TQO861E<BYP
M;2(I.PH@("`@("`@("`@("!]"@H@("`@("`@("`@("!O=71S*'%Q*%=R:71T
M96X@87,@(B1N86UE(BDI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*")&24Q%
M(BD["B`@("`@("`@("`@("1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H<W!R:6YT9B@*
M("`@("`@("`@("`@("`@("(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP
M=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M90H@("`@("`@("`@("`I*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT
M*2DI.PH@("`@("`@("`@("`D9F@M/G!R:6YT*"1C;VYT96YT*3L*("`@("`@
M("!]"B`@("!]"B`@("`C('U]?0H*("`@(",@3F]W('=R:71E(&]U="!T:&4@
M4$%2(&%N9"!M86=I8R!S=')I;F=S('M[>PH@("`@)'II<"T^=W)I=&54;T9I
M;&5(86YD;&4H)&9H*2!I9B`D>FEP.PH*("`@("1C86-H95]N86UE(#T@<W5B
M<W1R("1C86-H95]N86UE+"`P+"`T,#L*("`@(&EF("@A)&-A8VAE7VYA;64@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PH@("`@("`@(&UY
M("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI3
M2$$M/FYE=R@Q*2!]"B`@("`@("`@("`@('Q\(&5V86P@>R!R97%U:7)E($1I
M9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0H@("`@("`@("`@("!\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE
M=R!].PH*("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z
M.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@;7D@)'-H85]V97)S:6]N(#T@
M979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]('Q\(#`["B`@("`@("`@
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PH@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1O=70L(")B
M(BD@:68@*"1C='@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@
M("`@("`@:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PH@
M("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("`@("`@
M)&-T>"T^861D9FEL92@D9F@I.PH@("`@("`@("`@("`@("`@8VQO<V4H)&9H
M*3L*("`@("`@("`@("`@?0H@("`@("`@('T*"B`@("`@("`@)&-A8VAE7VYA
M;64@/2`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PH@("`@?0H@
M("`@)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?
M;F%M92D["B`@("`D8V%C:&5?;F%M92`N/2`B0T%#2$4B.PH@("`@)&9H+3YP
M<FEN="@D8V%C:&5?;F%M92D["B`@("`D9F@M/G!R:6YT*'!A8VLH)TXG+"`D
M9F@M/G1E;&P@+2!L96YG=&@H)&QO861E<BDI*3L*("`@("1F:"T^<')I;G0H
M(EQN4$%2+G!M7&XB*3L*("`@("1F:"T^8VQO<V4["B`@("!C:&UO9"`P-S4U
M+"`D;W5T.PH@("`@(R!]?7T*"B`@("!E>&ET.PI]"B,@?7U]"@HC(%!R97!A
M<F4@)'!R;V=N86UE(&EN=&\@4$%2(&9I;&4@8V%C:&4@>WM["GL*("`@(&QA
M<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*"B`@("!?9FEX7W!R;V=N
M86UE*"D["@H@("`@(R!.;W<@;&]A9"!T:&4@4$%2(&9I;&4@86YD('!U="!I
M="!I;G1O(%!!4CHZ3&EB0V%C:&4@>WM["B`@("!R97%U:7)E(%!!4CL*("`@
M(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*"@H@("`@>PH@("`@
M("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG?2`](%]?1DE,15]?(&EF("1>3R!N
M92`G35-7:6XS,B<["B`@("`@("`@<F5Q=6ER92!&:6QE.CI&:6YD.PH@("`@
M("`@(')E<75I<F4@07)C:&EV93HZ6FEP.PH@("`@?0H@("`@;7D@)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PH@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=SL*("`@("1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B
M)"$Z("1`(CL*("`@("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z
M("1`(CL*"B`@("!P=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PH@("`@)%!!
M4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["@H@("`@)'%U:65T(#T@
M(21%3E9[4$%27T1%0E5'?3L*("`@(&]U=',H<7$H7"1%3E9[4$%27U1%35!]
M(#T@(B1%3E9[4$%27U1%35!](BDI.PH*("`@(&EF("AD969I;F5D("1%3E9[
M4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0H@
M("`@("`@(&9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2![
M"B`@("`@("`@("`@(&YE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["B`@
M("`@("`@("`@(&UY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE
M.PH@("`@("`@("`@("!N97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*
M("`@("`@("`@("`@("`@(%X*("`@("`@("`@("`@("`@("\_<VAL:6(O"B`@
M("`@("`@("`@("`@("`H/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\*
M("`@("`@("`@("`@("`@("@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO
M*3\*("`@("`@("`@("`@("`@("A;7B]=*RD*("`@("`@("`@("`@("`@("0*
M("`@("`@("`@("`@?7@["B`@("`@("`@("`@(&UY("1E>'1R86-T7VYA;64@
M/2`D,3L*("`@("`@("`@("`@;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PH@("`@
M("`@("`@("!I9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M
M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PH@("`@("`@("`@("`@("`@;W5T<RAQ
M<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X
M:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@?2!E;'-E('L*
M("`@("`@("`@("`@("`@(&]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N
M86UE(B!T;R`B)&1E<W1?;F%M92(I*3L*("`@("`@("`@("`@("`@("1M96UB
M97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*("`@("`@("`@
M("`@("`@(&-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U
M>"(["B`@("`@("`@("`@('T*("`@("`@("!]"B`@("!]"B`@("`C('U]?0I]
M"B,@?7U]"@HC($EF('1H97)E)W,@;F\@;6%I;BYP;"!T;R!R=6XL('-H;W<@
M=7-A9V4@>WM["G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2D@
M>PH@("`@9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!
M;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@
M6R!P<F]G<F%M+G!L(%T*("`@("`@("0P(%L@+4)\+6(@72!;+4]O=71F:6QE
M72!S<F,N<&%R"BX*("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M92`]("0P(#T@<VAI9G0H0$%21U8I.PI]"B,@?7U]"@IS=6(@0W)E871E4&%T
M:"!["B`@("!M>2`H)&YA;64I(#T@0%\["B`@("`*("`@(')E<75I<F4@1FEL
M93HZ0F%S96YA;64["B`@("!M>2`H)&)A<V5N86UE+"`D<&%T:"P@)&5X="D@
M/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N86UE+"`H)UPN+BHG*2D[
M"B`@("`*("`@(')E<75I<F4@1FEL93HZ4&%T:#L*("`@(`H@("`@1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0H*<W5B(')E<75I<F5?;6]D=6QE<R!["B`@
M("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@
M)TU35VEN,S(G.PH*("`@(')E<75I<F4@;&EB.PH@("`@<F5Q=6ER92!$>6YA
M3&]A9&5R.PH@("`@<F5Q=6ER92!I;G1E9V5R.PH@("`@<F5Q=6ER92!S=')I
M8W0["B`@("!R97%U:7)E('=A<FYI;F=S.PH@("`@<F5Q=6ER92!V87)S.PH@
M("`@<F5Q=6ER92!#87)P.PH@("`@<F5Q=6ER92!#87)P.CI(96%V>3L*("`@
M(')E<75I<F4@17)R;F\["B`@("!R97%U:7)E($5X<&]R=&5R.CI(96%V>3L*
M("`@(')E<75I<F4@17AP;W)T97(["B`@("!R97%U:7)E($9C;G1L.PH@("`@
M<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&:6QE.CI3<&5C.PH@
M("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@0V]N9FEG.PH@("`@
M<F5Q=6ER92!)3SHZ2&%N9&QE.PH@("`@<F5Q=6ER92!)3SHZ1FEL93L*("`@
M(')E<75I<F4@0V]M<')E<W,Z.EIL:6(["B`@("!R97%U:7)E($%R8VAI=F4Z
M.EII<#L*("`@(')E<75I<F4@4$%2.PH@("`@<F5Q=6ER92!005(Z.DAE879Y
M.PH@("`@<F5Q=6ER92!005(Z.D1I<W0["B`@("!R97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*("`@(')E<75I<F4@871T<FEB=71E<SL*("`@(&5V
M86P@>R!R97%U:7)E($-W9"!].PH@("`@979A;"![(')E<75I<F4@5VEN,S(@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PH@("`@979A
M;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["B`@("!E=F%L
M('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PH@("`@979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"GT*"B,@5&AE($,@=F5R<VEO;B!O9B!T:&ES(&-O9&4@87!P96%R<R!I;B!M
M>6QD<B]M:W1M<&1I<BYC"B,@5&AI<R!C;V1E(&%L<V\@;&EV97,@:6X@4$%2
M.CI3971U<%1E;7`@87,@<V5T7W!A<E]T96UP7V5N=B$*<W5B(%]S971?<&%R
M7W1E;7`@>PH@("`@:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%
M3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PH@("`@("`@("1P87)?=&5M<"`]
M("0Q.PH@("`@("`@(')E='5R;CL*("`@('T*"B`@("!F;W)E86-H(&UY("1P
M871H("@*("`@("`@("`H;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!4
M35!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*("`@("`@("!Q=R@@0SI<7%1%
M35`@+W1M<"`N("D*("`@("D@>PH@("`@("`@(&YE>'0@=6YL97-S(&1E9FEN
M960@)'!A=&@@86YD("UD("1P871H(&%N9"`M=R`D<&%T:#L*("`@("`@("!M
M>2`D=7-E<FYA;64["B`@("`@("`@;7D@)'!W=6ED.PH@("`@("`@(",@9&]E
M<R!N;W0@=V]R:R!E=F5R>7=H97)E.@H@("`@("`@(&5V86P@>R@D<'=U:60I
M(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@)#X[?3L*"B`@("`@("`@:68@
M*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*("`@("`@("`@("`@
M)'5S97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["B`@("`@("`@?0H@("`@
M("`@(&5L<VEF("AD969I;F5D("1P=W5I9"D@>PH@("`@("`@("`@("`D=7-E
M<FYA;64@/2`D<'=U:60["B`@("`@("`@?0H@("`@("`@(&5L<V4@>PH@("`@
M("`@("`@("`D=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U53
M15)]('Q\("=365-414TG.PH@("`@("`@('T*("`@("`@("`D=7-E<FYA;64@
M/7X@<R]<5R]?+V<["@H@("`@("`@(&UY("1S=&UP9&ER(#T@(B1P871H)$-O
M;F9I9WM?9&5L:6U]<&%R+21U<V5R;F%M92(["B`@("`@("`@;6MD:7(@)'-T
M;7!D:7(L(#`W-34["B`@("`@("`@:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD
M(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["B`@("`@("`@
M("`@(&]P96X@*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PH@("`@("`@("`@
M("!S965K("1F:"P@+3$X+"`R.PH@("`@("`@("`@("!S>7-R96%D("1F:"P@
M;7D@)&)U9BP@-CL*("`@("`@("`@("`@:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["B`@("`@("`@("`@("`@("!S965K("1F:"P@+34X+"`R.PH@("`@("`@
M("`@("`@("`@<WES<F5A9"`D9F@L("1B=68L(#0Q.PH@("`@("`@("`@("`@
M("`@)&)U9B`]?B!S+UPP+R]G.PH@("`@("`@("`@("`@("`@)'-T;7!D:7(@
M+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D8G5F.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*("`@("`@("`@("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*("`@("`@("`@
M("`@("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG
M97-T.CI-1#4M/FYE=R!].PH*("`@("`@("`@("`@("`@(",@5V]R:V%R;W5N
M9"!F;W(@8G5G(&EN($1I9V5S=#HZ4TA!(#4N,S@@86YD(#4N,SD*("`@("`@
M("`@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI3
M2$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@("`@("`@("`@:68@*"1S:&%?
M=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@
M>PH@("`@("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)'!R;V=N86UE
M+"`B8B(I(&EF("@D8W1X*3L*("`@("`@("`@("`@("`@('T*("`@("`@("`@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`@("`@("`@(&EF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PH@("`@("`@("`@("`@
M("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@("`@("`@("`@
M("`@("1C='@M/F%D9&9I;&4H)&9H*3L*("`@("`@("`@("`@("`@("`@("`@
M("`@8VQO<V4H)&9H*3L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@
M("`@("`@("!]"@H@("`@("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#;VYF
M:6=[7V1E;&EM?6-A8VAE+2(@+B`H("1C='@@/R`D8W1X+3YH97AD:6=E<W0@
M.B`D;71I;64@*3L*("`@("`@("`@("`@?0H@("`@("`@("`@("!C;&]S92@D
M9F@I.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)$5.
M5GM005)?0TQ%04Y](#T@,3L*("`@("`@("`@("`@)'-T;7!D:7(@+CT@(B1#
M;VYF:6=[7V1E;&EM?71E;7`M)"0B.PH@("`@("`@('T*"B`@("`@("`@)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*("`@("`@("!M:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*("`@("`@("!L87-T.PH@("`@?0H*("`@("1P87)?=&5M<"`]
M("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\["GT*"G-U8B!?=&5M<&9I;&4@>PH@("`@;7D@*"1E>'0L("1C<F,I
M(#T@0%\["B`@("!M>2`H)&9H+"`D9FEL96YA;64I.PH*("`@("1F:6QE;F%M
M92`]("(D<&%R7W1E;7`O)&-R8R1E>'0B.PH*("`@(&EF("@D14Y6>U!!4E]#
M3$5!3GTI('L*("`@("`@("!U;FQI;FL@)&9I;&5N86UE(&EF("UE("1F:6QE
M;F%M93L*("`@("`@("!P=7-H($!T;7!F:6QE+"`D9FEL96YA;64["B`@("!]
M"B`@("!E;'-E('L*("`@("`@("!R971U<FX@*'5N9&5F+"`D9FEL96YA;64I
M(&EF("@M<B`D9FEL96YA;64I.PH@("`@?0H*("`@(&]P96X@)&9H+"`G/B<L
M("1F:6QE;F%M92!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["B`@("!R
M971U<FXH)&9H+"`D9FEL96YA;64I.PI]"@HC('-A;64@8V]D92!L:79E<R!I
M;B!005(Z.E-E='5P4')O9VYA;64Z.G-E=%]P<F]G;F%M90IS=6(@7W-E=%]P
M<F]G;F%M92!["B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@
M86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*("`@("`@("`D
M<')O9VYA;64@/2`D,3L*("`@('T*"B`@("`D<')O9VYA;64@?'P]("0P.PH*
M("`@(&EF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D
M14Y6>U!!4E]414U0?2D@/CT@,"D@>PH@("`@("`@("1P<F]G;F%M92`]('-U
M8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E
M;&EM?2D@*R`Q*3L*("`@('T*"B`@("!I9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PH@("`@("`@(&EF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M("`@("`@("`@("`@<F5T=7)N(&EF("US("1F:#L*("`@("`@("!]"B`@("`@
M("`@:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PH@("`@("`@
M("`@("`D<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*("`@("`@("`@("`@
M<F5T=7)N.PH@("`@("`@('T*("`@('T*"B`@("!F;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2![
M"B`@("`@("`@;F5X="!I9B!E>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D
M:7(@97$@)$5.5GM005)?5$5-4'T["B`@("`@("`@)&1I<B`]?B!S+UQ1)$-O
M;F9I9WM?9&5L:6U]7$4D+R\["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I
M<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S
M="D*("`@("`@("`@("`@:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O
M9VYA;64D0V]N9FEG>U]E>&5](CL*("`@("`@("`H*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(BDL(&QA<W0I"B`@("`@("`@
M("`@(&EF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE(CL*("`@
M('T*?0H*<W5B(%]F:7A?<')O9VYA;64@>PH@("`@)#`@/2`D<')O9VYA;64@
M?'P]("1%3E9[4$%27U!23T=.04U%?3L*("`@(&EF("AI;F1E>"@D<')O9VYA
M;64L("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B`@("`@("`@)'!R;V=N86UE
M(#T@(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PH@("`@?0H*("`@(",@
M6%A8("T@:&%C:R!T;R!M86ME(%!71"!W;W)K"B`@("!M>2`D<'=D(#T@*&1E
M9FEN960@)D-W9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*("`@("`@("`@
M("`@("`@(#H@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'
M971#=V0H*2`Z(&!P=V1@*3L*("`@(&-H;VUP*"1P=V0I.PH@("`@)'!R;V=N
M86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<12DO)'!W9"1#
M;VYF:6=[7V1E;&EM?2\["@H@("`@)$5.5GM005)?4%)/1TY!345](#T@)'!R
M;V=N86UE.PI]"@IS=6(@7W!A<E]I;FET7V5N=B!["B`@("!I9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["B`@("`@("`@<F5T=7)N.PH@
M("`@?2!E;'-E('L*("`@("`@("`D14Y6>U!!4E])3DE424%,25I%1'T@/2`R
M.PH@("`@?0H*("`@(&9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!3B!$14)5
M1R!#04-(12!04D]'3D%-12!!4D=#($%21U9?,"`I("D@>PH@("`@("`@(&1E
M;&5T92`D14Y6>R=005)?)RXD7WT["B`@("!]"B`@("!F;W(@*'%W+R!435!$
M25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B`@("`@("`@)$5.5GLG4$%27R<N
M)%]](#T@)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG
M4$%27T=,3T)!3%\G+B1??3L*("`@('T*"B`@("!M>2`D<&%R7V-L96%N(#T@
M(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@(CL*"B`@("!I9B`H
M)$5.5GM005)?5$5-4'TI('L*("`@("`@("!D96QE=&4@)$5.5GM005)?0TQ%
M04Y].PH@("`@?0H@("`@96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,
M7T-,14%.?2D@>PH@("`@("`@(&UY("1V86QU92`]('-U8G-T<B@D<&%R7V-L
M96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B`@("`@("`@)$5.5GM005)?
M0TQ%04Y](#T@)#$@:68@)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*
M("`@('T*?0H*<W5B(&]U=',@>PH@("`@<F5T=7)N(&EF("1Q=6EE=#L*("`@
M(&EF("@D;&]G9F@I('L*("`@("`@("!P<FEN="`D;&]G9F@@(D!?7&XB.PH@
M("`@?0H@("`@96QS92!["B`@("`@("`@<')I;G0@(D!?7&XB.PH@("`@?0I]
M"@IS=6(@:6YI=%]I;F,@>PH@("`@<F5Q=6ER92!#;VYF:6<["B`@("!P=7-H
M($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL
M('%W*`H@("`@("`@(&%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X
M<"!S:71E;&EB97AP"B`@("`@("`@=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`*("`@("D["GT*"B,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(PHC(%1H
M92!M86EN('!A8VMA9V4@9F]R('-C<FEP="!E>&5C=71I;VX*"G!A8VMA9V4@
M;6%I;CL*"G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD
M7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*"F1I92!Q<2AP87(N<&PZ
M($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@
M9FEL92!O<B!D:7)E8W1O<GE<;BD*("`@('5N;&5S<R`M92`D<')O9VYA;64[
M"@ID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*"GT["@HD.CI?7T52
M4D]2(#T@)$`@:68@)$`["GT*"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T52
M4D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@
M:68@)#HZ7U]%4E)/4CL*"C$["@HC;&EN92`Q,#$R"@I?7T5.1%]?"@``````
M``#_____T%%``.110`"@O@````````````!`P@``L&```/B]````````````
M`(3"```(8```\+T`````````````HL(```!@```(O@````````````"\PP``
M&&``````````````````````````````DL(```````!,P@``8L(``'#"````
M````1L0``#;$```FQ```$L0```;$``#VPP``YL,``-[#``#0PP``R,,``+##
M``"FPP``F,,``([#``""PP``=,,``&K#``!4Q```5L,``$;#```ZPP``,,,`
M`";#```:PP``$,,```;#``#\P@``\L(``.+"``#8P@``SL(``,3"``"ZP@``
ML,(``&;$``!ZQ```8,,````````LP@``&L(```3"``#VP0``Y,$``,3!``"L
MP0``FL$``(3!``!VP0``:L$``%K!``!.P0``/L$``"K!```8P0``",$``/3`
M``#DP```U,```,;```"RP```HL```(K```!VP```7,```$S````\P```)L``
M`!+```#^OP``[K\``-2_``#"OP``LK\``)Z_``".OP``?+\``&B_``!:OP``
M2+\```````"X!&)O;W1?5VEN,S)#3U)%``!3`U!E<FQ?;F5W6%,``%D"4&5R
M;%]G971?8V]N=&5X=```MP1B;V]T7T1Y;F%,;V%D97(`Q`!097)L7TE,24]?
M<'1R`*`!4&5R;%])<W1A=&)U9E]P='(`QP!097)L7TE-96U?<'1R`,L`4&5R
M;%])4')O8U]P='(``+0#4&5R;%]S879E7V1E<W1R=6-T;W)?>```0`)097)L
M7V1O=6YW:6YD`+P!4&5R;%])=&]P7V5N=E]P='(`:P%097)L7TEP87)S97)?
M<'1R```4`5!E<FQ?265V86Q?<F]O=%]P='(`1P-097)L7VYE=U-6<'8``&`!
M4&5R;%]);W!?<'1R``#T`%!E<FQ?26-U<G-T86-K:6YF;U]P='(``"H!4&5R
M;%]):6Y?979A;%]P='(`&@)097)L7V-R;V%K7VYO8V]N=&5X=```P@!097)L
M7TE$:7)?<'1R`.@`4&5R;%])8V]M<&-V7W!T<@``^@)097)L7VUG7W-E=`!+
M!%!E<FQ?<W9?<V5T<'8`!0)097)L7V%V7W-H:69T`/<#4&5R;%]S=E\R<'9?
M9FQA9W,`_@%097)L7V%V7V9E=&-H`'T"4&5R;%]G=E]F971C:'!V`+4!4&5R
M;%])=&%I;G1E9%]P='(`?@1097)L7W-Y<U]T97)M`,($<&5R;%]F<F5E`,$$
M<&5R;%]D97-T<G5C=`#%!'!E<FQ?<G5N``#$!'!E<FQ?<&%R<V4``*<#4&5R
M;%]S869E<WES;6%L;&]C```%`%!,7VUE;6]R>5]W<F%P```7`5!E<FQ?265X
M:71?9FQA9W-?<'1R``!N`5!E<FQ?27!E<FQ?9&5S=')U8W1?;&5V96Q?<'1R
M`,`$<&5R;%]C;VYS=')U8W0``+H$<&5R;%]A;&QO8P``FP!097)L7T=D;U]U
M;F1U;7!?<'1R`'H$4&5R;%]S>7-?:6YI=#,``%0#4&5R;%]N97=84U]F;&%G
M<P``<&5R;#4Q,"YD;&P`)`%'971-;V1U;&5&:6QE3F%M94$``+0`1G)E94QI
M8G)A<GD`)@%'971-;V1U;&5(86YD;&5!``!+15).14PS,BYD;&P``-<`1V5T
M57-E<DYA;65!``!!1%9!4$DS,BYD;&P``+("<W!R:6YT9@"X`G-T<F-M<```
MQP)S=')T;VL``+X"<W1R;&5N``#%`G-T<G-T<@``;0!?7W!?7V5N=FER;VX`
M`)@";65M;6]V90#!`G-T<FYC<'D`P`)S=')N8VUP`,@`7V5R<FYO``#!`5]S
M=')I8VUP``""`5]M:V1I<@``C@%?<&-T>7!E`!4!7VES8W1Y<&4``&$`7U]M
M8E]C=7)?;6%X``"7`FUE;6-P>0``F0)M96US970``)D!7W)M9&ER``#?`%]F
M:6YD8VQO<V4``.(`7V9I;F1N97AT`-T!7W5N;&EN:P#@`%]F:6YD9FER<W0`
M`+\!7W-T<F1U<`#%`5]S=')N:6-M<`!-4U9#4E0N9&QL``#3`%]E>&ET`$@`
M7UAC<'1&:6QT97(`20)E>&ET``!D`%]?<%]?7VEN:71E;G8`6`!?7V=E=&UA
M:6YA<F=S``\!7VEN:71T97)M`(,`7U]S971U<V5R;6%T:&5R<@``G0!?861J
M=7-T7V9D:78``&H`7U]P7U]C;VUM;V1E``!O`%]?<%]?9FUO9&4``($`7U]S
M971?87!P7W1Y<&4``,H`7V5X8V5P=%]H86YD;&5R,P``MP!?8V]N=')O;&9P
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````````````<T$``(-!``/____]<````
M.P```'!E<FQX<VDN8P```$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!7
M:6XS,D-/4D4Z.F)O;W1S=')A<`````!005)?5$5-4`````!005)?4%)/1TY!
M344`````4$%27U!23T=.04U%`````"X```!005)?4%)/1TY!344`````)7,E
M<R5S``!005)?4%)/1TY!344`````4$%27U!23T=.04U%`````"X````N````
M7U]%3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("``````4$523#5,24(`
M````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,25I%
M1`!005)?4U!!5TY%1`!005)?5$5-4`````!005)?0TQ%04X```!005)?1$5"
M54<```!005)?0T%#2$4```!005)?4%)/1TY!344`````4$%27T%21T,`````
M4$%27T%21U9?,```4$%27T=,3T)!3%]$14)51P````!005)?1$5"54<```!0
M05)?1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-
M4`!005)?5$5-4`````!005)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3@``
M`$-,14%.````4$%27T-,14%./0``4$%27T-,14%./0``4$%27T-,14%./0``
M4$%27T-,14%.````,0```%!!4E])3DE424%,25I%1`!005)?0TQ%04X```!,
M1%],24)205)97U!!5$@`3$1?3$E"4D%265]0051(`$Q)0E!!5$@`3$E"4$%4
M2`!,24)205)97U!!5$@`````3$E"4D%265]0051(`````%!!5$@`````4$%4
M2`````!$64Q$7TQ)0E)!4EE?4$%42````$193$1?3$E"4D%265]0051(````
M)7,E<R5S``!#.EQ414U0`$,Z7%1%35``7````%P````N````+@```%!!4E]4
M35!$25(``%!!4E]435!$25(``%1-4$1)4@``5$U01$E2``!414U01$E2`%1%
M35!$25(`5$5-4`````!414U0`````%1-4`!435``55-%4@````!54T52````
M`%5315).04U%`````%5315).04U%`````'!A<BT`````4$%27U1%35``````
M4UE35$5-``!7:6Y$:7(``"5S7'1E;7``)7,E<R5S)7,`````4$%42`````!P
M87)L+F5X90````!P87)L+F5X90`````N<&%R`````"5S)7-C86-H92TE<R5S
M```E,#)X`````"5S)7-C86-H92TE<R5S```Q````4$%27T-,14%.````)7,E
M<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````4$%27U1%35``````
M<&%R+0`````E<UPJ+BH``%P````E<UPE<P```"5S``!<+@``7"X``%PN+@!0
M05)?24Y)5$E!3$E:140`05)'5@`````8````<&5R;"YE>&4`````,````%!!
M4E]04D]'3D%-10````!005)?5$5-4``````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!T96UP;W)A<GD@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`M(&%B;W)T
M:6YG('=I=&@@)6DN"@```"5S```M90``+2T``%!!4E]34$%73D5$`%!!4E]4
M14U0`````$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````&#50`#I6P``<&%R+G!L
M``````````````$`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````,``P```"@``(`.````2```
M@!````!@``"````````````````````"``$```!X``"``@```)```(``````
M``````````````$`90```*@``(````````````````````$``0```,```(``
M``````````````````$``````-@```````````````````````$``````.@`
M``````````````````````$``````/@```````````````````````$`````
M``@!``"8XP``:`4``````````````.D``*@(`````````````*CQ```B````
M```````````@X0``=`(```````````````````````!T`C0```!6`%,`7P!6
M`$4`4@!3`$D`3P!.`%\`20!.`$8`3P``````O03O_@```0``````````````
M````````/P````$````$``0``0```````````````````-0!```!`%,`=`!R
M`&D`;@!G`$8`:0!L`&4`20!N`&8`;P```+`!```!`#``-``P`#``,``T`&(`
M,````!@````!`$,`;P!M`&T`90!N`'0`<P```"`````!`$,`;P!M`'``80!N
M`'D`3@!A`&T`90``````*`````$`1@!I`&P`90!$`&4`<P!C`'(`:0!P`'0`
M:0!O`&X``````"`````!`$8`:0!L`&4`5@!E`'(`<P!I`&\`;@``````(```
M``$`20!N`'0`90!R`&X`80!L`$X`80!M`&4````D`````0!,`&4`9P!A`&P`
M0P!O`'``>0!R`&D`9P!H`'0````H`````0!,`&4`9P!A`&P`5`!R`&$`9`!E
M`&T`80!R`&L`<P``````*`````$`3P!R`&D`9P!I`&X`80!L`$8`:0!L`&4`
M;@!A`&T`90```"`````!`%``<@!I`'8`80!T`&4`0@!U`&D`;`!D````(```
M``$`4`!R`&\`9`!U`&,`=`!.`&$`;0!E```````D`````0!0`'(`;P!D`'4`
M8P!T`%8`90!R`',`:0!O`&X````@`````0!3`'``90!C`&D`80!L`$(`=0!I
M`&P`9````$0````!`%8`80!R`$8`:0!L`&4`20!N`&8`;P``````)``$````
M5`!R`&$`;@!S`&P`80!T`&D`;P!N````````!+`$`````"@````0````(```
M``$`"`````````$```````````````$````!```&!@8`!`0$``("`@``````
M0D)"`)V=G0!N;FX`@8&!`+&QL0#___\`<W-S`)^?GP!86%@`LK*R`/W]_0!K
M:VL`_/S\`-?7UP`6%A8`VMK:`):6E@".CHX`1D9&`,O+RP`+"PL`H*"@`/[^
M_@#)R<D`P<'!``,#`P`1$1$`DY.3`+.SLP#N[NX`]/3T`./CXP#EY>4`HJ*B
M`+JZN@"OKZ\`!P<'`'%Q<0"UM;4`]?7U`(F)B0"*BHH`-#0T`.CHZ``U-34`
M6EI:`+>WMP#8V-@`T-#0`!T='0`,#`P`CX^/`+Z^O@!M;6T`"0D)`)N;FP`O
M+R\`S<W-`-G9V0`9&1D`34U-`$1$1`!04%``/#P\`&1D9`#"PL(`,C(R``@(
M"``-#0T`#P\/````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````4%!04%!04%!04%!04%!`0$!-4`C!4$Q0T%!
M1$4N`0$!`0$!`04!/!<7`0$3`0$!`0$!`0$5`0$F%0$!#P$!`0$!`0$!$P$1
M`04U`28!`0$!`0$!`2(2$#$/!0$@`0$!`0$!`0$0"B`B%14N(2X!`0$!`1\@
M(1`B$",C)28G`0$!`240$!`0$!`0$!`710$!`4$0$!`0$!`0$!`0$!<!`0$/
M$!`5$!`0$!`0$!`!`0$!$A`0$Q\0$!`0$!`'`0$!`2`0$!`!#Q`0$!`1`0$!
M`0$'(!`*`0$%$!`0,0$!`0$!`0$!`0$!`4$%#P$!`0$!`0$!`0$!`0$!`0$!
M`0$!`8`!``#``0``X`,``/`#``#P`P``\`,``.`#``#``0``@`$``(`!``"`
M`P``@`,````'````!P``C@\``/\?```H````(````$`````!``@````````$
M```````````````!`````0````````$!`0`"`@(``P,#``0$!``%!04`!@8&
M``<'!P`("`@`"0D)``H*"@`+"PL`#`P,``T-#0`.#@X`#P\/`!`0$``1$1$`
M$A(2`!,3$P`4%!0`%145`!86%@`7%Q<`&!@8`!D9&0`:&AH`&QL;`!P<'``=
M'1T`'AX>`!\?'P`@("``(2$A`"(B(@`C(R,`)"0D`"4E)0`F)B8`)R<G`"@H
M*``I*2D`*BHJ`"LK*P`L+"P`+2TM`"XN+@`O+R\`,#`P`#$Q,0`R,C(`,S,S
M`#0T-``U-34`-C8V`#<W-P`X.#@`.3DY`#HZ.@`[.SL`/#P\`#T]/0`^/CX`
M/S\_`$!`0`!!04$`0D)"`$-#0P!$1$0`145%`$9&1@!'1T<`2$A(`$E)20!*
M2DH`2TM+`$Q,3`!-34T`3DY.`$]/3P!04%``45%1`%)24@!34U,`5%14`%55
M50!65E8`5U=7`%A86`!965D`6EI:`%M;6P!<7%P`75U=`%Y>7@!?7U\`8&!@
M`&%A80!B8F(`8V-C`&1D9`!E964`9F9F`&=G9P!H:&@`:6EI`&IJ:@!K:VL`
M;&QL`&UM;0!N;FX`;V]O`'!P<`!Q<7$`<G)R`'-S<P!T='0`=75U`'9V=@!W
M=W<`>'AX`'EY>0!Z>GH`>WM[`'Q\?`!]?7T`?GY^`']_?P"`@(``@8&!`(*"
M@@"#@X,`A(2$`(6%A0"&AH8`AX>'`(B(B`")B8D`BHJ*`(N+BP",C(P`C8V-
M`(Z.C@"/CX\`D)"0`)&1D0"2DI(`DY.3`)24E`"5E94`EI:6`)>7EP"8F)@`
MF9F9`)J:F@";FYL`G)R<`)V=G0">GIX`GY^?`*"@H`"AH:$`HJ*B`*.CHP"D
MI*0`I:6E`*:FI@"GIZ<`J*BH`*FIJ0"JJJH`JZNK`*RLK`"MK:T`KJZN`*^O
MKP"PL+``L;&Q`+*RL@"SL[,`M+2T`+6UM0"VMK8`M[>W`+BXN`"YN;D`NKJZ
M`+N[NP"\O+P`O;V]`+Z^O@"_O[\`P,#``,'!P0#"PL(`P\/#`,3$Q`#%Q<4`
MQL;&`,?'QP#(R,@`R<G)`,K*R@#+R\L`S,S,`,W-S0#.SLX`S\_/`-#0T`#1
MT=$`TM+2`-/3TP#4U-0`U=75`-;6U@#7U]<`V-C8`-G9V0#:VMH`V]O;`-S<
MW`#=W=T`WM[>`-_?WP#@X.``X>'A`.+BX@#CX^,`Y.3D`.7EY0#FYN8`Y^?G
M`.CHZ`#IZ>D`ZNKJ`.OKZP#L[.P`[>WM`.[N[@#O[^\`\/#P`/'Q\0#R\O(`
M\_/S`/3T]`#U]?4`]O;V`/?W]P#X^/@`^?GY`/KZ^@#[^_L`_/S\`/W]_0#^
M_OX`____`#0T-#P\/#P\/#P\/#P\/#P\/#P\/#P\/"P,!`0$!`0$7+34U-34
MU-34U-34W-34U-34U-34U-34M#11!`0$!`1DS.ST]/3\]/ST]/3\]/ST_/3\
M_/ST].S$-%%1!`0$!&3$Y.ST]/3T]/3T]/3T]/3T]/3T]/3L[+PT45%1!`0$
M9,3D[.SLY.SL[.3DY.3L[.3LY.SL[.SDO#1145%1!`1DO.3L[*R,K-3$E)2<
ME(R,E)24G)R<[-R\-%%145%1!&2\W.3LY,11E*QDY*1,-"Q<Q,Q1M-3DW+PT
M45%145%19+S<Y.3LY.11A'3DC&RDG&R,O'2LU.3<O#0$!`0$!`1DO-SDY.SD
MY+Q1C-34C*S,=,S<I%'$Y-R\-`0$!`0$!&2\W.3DY.3DW(Q\G+1\A)QLS.2\
M=,3DW+0T!`0$!`0$7+S<W.3DY.34G*1<E(S,/)1DS+R,4=S4M#0$!`0$!`1D
MM-3<W-SDW(R,K"R\M,Q:Q&2<;)2DW-2T-`0$!`0$!%RTU-S<Y-S<=)343*3T
MC#S4=)1TG$S<S+0T!`0$!`0$9+34W-S<Y-QT4?1TA.S,9.1\;*2T;*34M#0$
M!`0$!`1DM,S<W,Q\C(2T_,S$_/2T_+QDS*R$4;RL-`0$!`0$!%RTS-3,C*3<
MW.S\_/S\_/3\[+3LK'R44:PT!`0$!`0$7*S,S&R<]/S\_/S\_/S\_/S\_/S$
ME(Q1K#0$!`0$!`1<K,2\?.3\_/S\_/S\_/S\_/S\_.S,K%&L-`0$!`0$!%RL
MM$S$_/S\[/3\_/S\_/S\_/S\]+Q1Q*PT!`0$!`0$7*RT3-3\_/2TW/S\_/S\
M_/S\_/S,4<S$I#0$!`0$!`1<K,2D4?S\_+2<]/S\_/S\_/S\])11S,2D+`0$
M!`0$!%RDI%&$[/S\S&2T[/S\_/S\_/S4;*S,O*0T!`0$!`0$7*1D=+ST_/S$
M482<Y/S\_/S\Y(Q1S,S$I#0$!`0$!`1<I&R,Y/3\_)Q1S%&4[/S\_/R\=,S,
MQ+R<+`0$!`0$!%RDK&1<9*2D4:S,Q'24Y/3\Y%&\S,S$O)PT!`0$!`0$7*2T
MO+R,45'$Q,S,K%%\?)1L?+S,Q,2\G"P$!`0$!`1<G+S$Q,3$Q,3$Q,3$Q%%1
M45&\Q,3$Q+2<-`0$!`0$!%2<M,3$Q,3$Q,3$Q,3$Q,3$Q,3$Q,2\M)PL!`0$
M!`0$5)R\Q,2\O+R\O+R\O+R\O+R\O+R\O+RTG"P$!`0$!`1<G+3$O+2TM+2T
MM+2TM+2TM+2TM+2TM*R<+`0$!`0$!%2$E)R<E)24E)24E)24E)24E)24E)24
ME(0D!`0$!`0$1%1<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<7%Q<5#0$!`0$!`0````_
M````'P````\````'`````P````$`````````/P```#\````_````/P```#\`
M```_````/P```#\````_````/P```#\````_````/P```#\````_````/P``
M`#\````_````/P```#\````_````/P```#\````_````/P```0`"`!`0```!
M``@`:`4```$`("````$`"`"H"````@``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````$Y",3``````9[R33`$```!#.EPN8W!A;EQB=6EL
H9%Q005(M4&%C:V5R+3$N,#`W+6UB051':5QM>6QD<EQP87(N<&1B````
